import { reactive, toRefs, resolveDirective, withDirectives, openBlock, createElementBlock, createElementVNode, vModelSelect, vModelText, createCommentVNode, vModelCheckbox, vShow, createStaticVNode } from 'vue';

function _typeof(obj) {
  "@babel/helpers - typeof";

  if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
    _typeof = function (obj) {
      return typeof obj;
    };
  } else {
    _typeof = function (obj) {
      return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
    };
  }

  return _typeof(obj);
}

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    if (enumerableOnly) symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    });
    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(Object(source), true).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(Object(source)).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

// 创建一个简单的store状态管理

var storeState = reactive({
  isViewer: false,
  //viewer初始化标志
  changeLayers: 0,
  //图层改变加载完毕监听
  changeGeometrys: 0 //三维分析体改变标志

});
var actions = {
  setIsViewer: function setIsViewer(newValue) {
    storeState.isViewer = newValue;
  },
  setChangeLayers: function setChangeLayers(newValue) {
    storeState.changeLayers += 1;
  },
  setGeometrys: function setGeometrys(newValue) {
    storeState.changeGeometrys += 1;
  }
}; // 全局公共数据

var storeDate = {
  geometrys: {},
  //存储当前存在的三位空间查询体：如天际线体，可视域体
  layers: null
};

// 添加s3m

function addS3mLayers(scps, callback) {
  //scps:[{ url, options:{name}]}  无返回值
  var promiseArray = [];

  try {
    if (scps) {
      //加载scps
      scps.forEach(function (scp) {
        promiseArray.push(viewer.scene.addS3MTilesLayerByScp(scp.url, scp.options));
      });
    }

    promiseWhen(promiseArray, callback, 'S3M');
  } catch (e) {
    var widget = viewer.cesiumWidget;

    if (widget._showRenderLoopErrors) {
      var title = "渲染时发生错误，已停止渲染。";
      widget.showErrorPanel(title, undefined, e);
    }
  }
}

function addScene(url, options, callback) {
  //无返回值options:{SceneToken,autoSetView}
  if (options && options.SceneToken) {
    Cesium.Credential.CREDENTIAL = new Cesium.Credential(options.SceneToken);
  }

  var flag = true;

  if (options && options.autoSetView) {
    flag = options.autoSetView;
  }

  if (checkURL(url)) {
    try {
      var s = [viewer.scene.open(url, undefined, {
        'autoSetView': flag
      })];
      promiseWhen(s, callback, 'SCENE');
    } catch (e) {
      var widget = viewer.cesiumWidget;

      if (widget._showRenderLoopErrors) {
        var title = "渲染时发生错误，已停止渲染。";
        widget.showErrorPanel(title, undefined, e);
      }
    }
  }
}

function addTerrainLayer(LayerURL, isSct) {
  try {
    viewer.terrainProvider = new Cesium.CesiumTerrainProvider({
      url: LayerURL,
      isSct: isSct //地形服务源自SuperMap iServer发布时需设置isSct为true

    });
  } catch (e) {
    var widget = viewer.cesiumWidget;

    if (widget._showRenderLoopErrors) {
      var title = "渲染时发生错误，已停止渲染。";
      widget.showErrorPanel(title, undefined, e);
    }
  }
}

function addImageLayer(LayerURL) {
  // 返回img图层layer
  try {
    var layer = viewer.imageryLayers.addImageryProvider(new Cesium.SuperMapImageryProvider({
      url: LayerURL
    }));
    return layer;
  } catch (e) {
    var widget = viewer.cesiumWidget;

    if (widget._showRenderLoopErrors) {
      var title = "渲染时发生错误，已停止渲染。";
      widget.showErrorPanel(title, undefined, e);
    }
  }
}

function addMvtLayer(LayerURL, name, callback) {
  // 返回img图层layer
  try {
    var mvtMap = viewer.scene.addVectorTilesMap({
      url: LayerURL,
      canvasWidth: 512,
      name: name || 'mvt',
      viewer: viewer
    });
    Cesium.when(mvtMap.readyPromise, function (data) {
      var bounds = mvtMap.rectangle;
      viewer.scene.camera.flyTo({
        destination: new Cesium.Cartesian3.fromRadians((bounds.east + bounds.west) * 0.5, (bounds.north + bounds.south) * 0.5, 10000),
        duration: 0,
        orientation: {
          heading: 0,
          roll: 0
        }
      });
      actions.setChangeLayers();
      callback(mvtMap);
    });
    return mvtMap;
  } catch (e) {
    var widget = viewer.cesiumWidget;

    if (widget._showRenderLoopErrors) {
      var title = "渲染时发生错误，已停止渲染。";
      widget.showErrorPanel(title, undefined, e);
    }
  }
}

function promiseWhen(promiseArray, callback, type) {
  Cesium.when.all(promiseArray, function (layers) {
    storeDate.layers = viewer.scene.layers.layerQueue;
    actions.setChangeLayers();
    callback(layers[0], type);
    storeDate.layers.forEach(function (s3mlayer) {
      if (!s3mlayer.visibleDistanceMax || s3mlayer.visibleDistanceMax > 12000) {
        s3mlayer.visibleDistanceMax = 12000; //设置模型最可见距离
      }
    });
  }, function (e) {
    var widget = viewer.cesiumWidget;

    if (widget._showRenderLoopErrors) {
      var title = '请检查url地址是否正确？';
      widget.showErrorPanel(title, undefined, e);
    }
  });
}

function checkURL(url) {
  if (url === null || url === "") {
    return false;
  }

  if (url.charAt(0) == '"' || url.charAt(0) == "'") {
    var reg = /^['|"](.*)['|"]$/;
    url = url.replace(reg, "$1");
  }

  return true;
}

function layersDelete(type, id_name, callback) {
  switch (type) {
    case "S3M":
      viewer.scene.layers.remove(id_name);
      actions.setChangeLayers(); //图层改变全局响应触发

      callback();
      break;

    case "IMG":
      var img_layer;

      if (typeof id_name === 'nunber') {
        img_layer = viewer.imageryLayers.get(id_name);
      } else {
        var img_layers = viewer.imageryLayers._layers;

        for (var i = 0; i < img_layers.length; i++) {
          if (img_layers[i].imageryProvider.tablename && img_layers[i].imageryProvider.tablename === id_name) {
            img_layer = img_layers[i];
          }
        }
      }

      if (img_layer) {
        viewer.imageryLayers.remove(img_layer);
        actions.setChangeLayers();
        callback();
      }

      break;

    case "TERRAIN":
      viewer.terrainProvider = new Cesium.EllipsoidTerrainProvider();
      actions.setChangeLayers();
      callback();
      break;

    case "MVT":
      viewer.scene.removeVectorTilesMap(id_name);
      actions.setChangeLayers();
      callback();
      break;
  }
}

var layerManagement = {
  addS3mLayers: addS3mLayers,
  addScene: addScene,
  addTerrainLayer: addTerrainLayer,
  addImageLayer: addImageLayer,
  layersDelete: layersDelete,
  addMvtLayer: addMvtLayer
};

/*
* 常用工具类
*/
//axios本版本不支持jsonp
var axiosJsonp = function axiosJsonp(url) {
  if (!url) {
    console.error('Axios.JSONP 至少需要一个url参数!');
    return;
  }

  return new Promise(function (resolve, reject) {
    window.jsonCallBack = function (result) {
      resolve(result);
    };

    var JSONP = document.createElement("script");
    JSONP.type = "text/javascript";
    JSONP.src = "".concat(url, "&callback=jsonCallBack");
    document.getElementsByTagName("head")[0].appendChild(JSONP);
    setTimeout(function () {
      document.getElementsByTagName("head")[0].removeChild(JSONP);
    }, 500);
  });
}; //判断两数组或对象相等


var isEqualArr = function isEqualArr(arg1, arg2) {
  if (!arg1 || !arg2) return true;
  var bol = true;

  if (Object.keys(arg1).length != Object.keys(arg2).length) {
    return false;
  }

  for (var key in arg1) {
    if (_typeof(arg1[key]) == 'object') {
      bol = isSame(arg1[key], arg2[key]);

      if (!bol) {
        break;
      }
    } else if (arg1[key] != arg2[key]) {
      bol = false;
      break;
    }
  }

  return bol;
}; //坐标转化
//笛卡尔转经纬度


var CartesiantoDegrees = function CartesiantoDegrees(Cartesians) {
  var array = [].concat(Cartesians);
  var positions = [];

  for (var i = 0, len = array.length; i < len; i++) {
    var cartographic = Cesium.Cartographic.fromCartesian(array[i]);
    var longitude = Cesium.Math.toDegrees(cartographic.longitude);
    var latitude = Cesium.Math.toDegrees(cartographic.latitude);
    var h = cartographic.height;

    if (positions.indexOf(longitude) == -1 && positions.indexOf(latitude) == -1) {
      positions.push(longitude);
      positions.push(latitude);
      positions.push(h);
    }
  }

  return positions;
}; //笛卡尔转经纬度(每个点是独立的对象)


var CartesiantoDegreesObjs = function CartesiantoDegreesObjs(Cartesians) {
  var array = [].concat(Cartesians);
  var positions = [];

  for (var i = 0, len = array.length; i < len; i++) {
    var cartographic = Cesium.Cartographic.fromCartesian(array[i]);
    var obj = {
      longitude: Cesium.Math.toDegrees(cartographic.longitude),
      latitude: Cesium.Math.toDegrees(cartographic.latitude),
      height: cartographic.height
    };
    positions.push(obj);
  }

  return positions;
}; // 弧度转经纬度


var CartographictoDegrees = function CartographictoDegrees(wgsPosition) {
  var longitude = Cesium.Math.toDegrees(wgsPosition.longitude);
  var latitude = Cesium.Math.toDegrees(wgsPosition.latitude);
  var height = wgsPosition.height;
  return [longitude, latitude, height];
}; //去重函数  数组


var unique = function unique(arr) {
  var res = [];
  var json = {};

  for (var i = 0; i < arr.length; i++) {
    if (!json[arr[i]]) {
      res.push(arr[i]);
      json[arr[i]] = 1;
    }
  }

  return res;
}; // 获取渐变色函数


function gradientColors(start, end, steps, gamma) {
  var i,
      j,
      ms,
      me,
      output = [],
      so = [];
  gamma = gamma || 1;

  var normalize = function normalize(channel) {
    return Math.pow(channel / 255, gamma);
  };

  start = parseColor(start).map(normalize);
  end = parseColor(end).map(normalize);

  for (i = 0; i < steps; i++) {
    ms = i / (steps - 1);
    me = 1 - ms;

    for (j = 0; j < 3; j++) {
      so[j] = pad(Math.round(Math.pow(start[j] * me + end[j] * ms, 1 / gamma) * 255).toString(16));
    }

    output.push('#' + so.join(''));
  }

  return output;

  function parseColor(hexStr) {
    return hexStr.length === 4 ? hexStr.substr(1).split('').map(function (s) {
      return 0x11 * parseInt(s, 16);
    }) : [hexStr.substr(1, 2), hexStr.substr(3, 2), hexStr.substr(5, 2)].map(function (s) {
      return parseInt(s, 16);
    });
  }

  function pad(s) {
    return s.length === 1 ? '0' + s : s;
  }
}

function getAngleAndRadian(pointA, pointB) {
  //建立以点A为原点，X轴为east,Y轴为north,Z轴朝上的坐标系
  var transform = Cesium.Transforms.eastNorthUpToFixedFrame(pointA); //向量AB

  var positionvector = Cesium.Cartesian3.subtract(pointB, pointA, new Cesium.Cartesian3()); //因transform是将A为原点的eastNorthUp坐标系中的点转换到世界坐标系的矩阵
  //AB为世界坐标中的向量
  //因此将AB向量转换为A原点坐标系中的向量，需乘以transform的逆矩阵。

  var vector = Cesium.Matrix4.multiplyByPointAsVector(Cesium.Matrix4.inverse(transform, new Cesium.Matrix4()), positionvector, new Cesium.Cartesian3()); //归一化

  var direction = Cesium.Cartesian3.normalize(vector, new Cesium.Cartesian3()); //heading

  var heading1 = Math.atan2(direction.y, direction.x) - Cesium.Math.PI_OVER_TWO;
  var radian = Cesium.Math.TWO_PI - Cesium.Math.zeroToTwoPi(heading1);
  var angle = radian * (180 / Math.PI);

  if (angle < 0) {
    angle = angle + 360;
  }

  return {
    angle: angle,
    radian: radian
  };
}

function getPitch(pointA, pointB) {
  var transfrom = Cesium.Transforms.eastNorthUpToFixedFrame(pointA);
  var vector = Cesium.Cartesian3.subtract(pointB, pointA, new Cesium.Cartesian3());
  var direction = Cesium.Matrix4.multiplyByPointAsVector(Cesium.Matrix4.inverse(transfrom, transfrom), vector, vector);
  Cesium.Cartesian3.normalize(direction, direction); //因为direction已归一化，斜边长度等于1，所以余弦函数等于direction.z

  var radian = Cesium.Math.PI_OVER_TWO - Cesium.Math.acosClamped(direction.z);
  var angle = radian * (180 / Math.PI);

  if (angle < 0) {
    angle = angle + 360;
  }

  return {
    angle: angle,
    radian: radian
  };
}

var tool = {
  axiosJsonp: axiosJsonp,
  isEqualArr: isEqualArr,
  CartesiantoDegrees: CartesiantoDegrees,
  CartesiantoDegreesObjs: CartesiantoDegreesObjs,
  unique: unique,
  gradientColors: gradientColors,
  getAngleAndRadian: getAngleAndRadian,
  CartographictoDegrees: CartographictoDegrees,
  getPitch: getPitch
};

var script = {
  name: "Sm3dCustomService",
  props: {
    //点击确定时回调
    addCallback: {
      type: Function
    },
    //点击取消时回调
    clearCallback: {
      type: Function
    },
    getLayerName: {
      type: Function
    }
  },
  setup: function setup(props) {
    // 设置默认值数据
    var state = reactive({
      layersType: "SCENE",
      layerURL: null,
      layerName: null,
      isAddToken: false,
      token: null,
      isSct: false
    });

    var addCallback = function addCallback() {};

    var clearCallback = function clearCallback() {};

    var getLayerName = function getLayerName() {};

    if (props && props.clearCallback) {
      clearCallback = props.clearCallback;
    }

    if (props && props.addCallback) {
      addCallback = props.addCallback;
    }

    if (props && props.getLayerName) {
      getLayerName = props.getLayerName;
    }

    function check() {
      if (!state.layerURL || state.layerURL === "") {
        tool.Message.warnMsg("请填写正确的URL");
        return false;
      }

      if (state.layersType != "SCENE" && (!state.layerName || state.layerName === "")) {
        tool.Message.warnMsg("请补充图层名称");
        return false;
      }

      if (state.isAddToken && !state.token) {
        tool.Message.warnMsg("勾选token后请填写token");
        return false;
      }

      return true;
    }

    function checkLayersType() {
      var arr = state.layerURL.split('/');
      var layer_type = arr[arr.length - 1];
      if (layer_type === 'realspace' && state.layersType != "SCENE") return false;
      if (layer_type === 'config' && state.layersType != "S3M") return false;
      if (layer_type === 'image' && state.layersType != "IMG") return false;
      return true;
    }

    function addLayer() {
      if (!checkLayersType()) {
        tool.Message.warnMsg("请检查添加类型是否正常？");
        return;
      }
      getLayerName(state.layerName);

      switch (state.layersType) {
        case "SCENE":
          if (check()) {
            var options = {};
            if (state.isAddToken) options.SceneToken = token;
            layerManagement.addScene(state.layerURL, options, addCallback);
          }

          break;

        case "S3M":
          if (check()) {
            var scps = [{
              url: state.layerURL,
              options: {
                name: state.layerName
              }
            }];
            layerManagement.addS3mLayers(scps, addCallback);
          }

          break;

        case "IMG":
          if (check()) {
            var layer = layerManagement.addImageLayer(state.layerURL);
            addCallback(layer, "IMG");
          }

          break;

        case "TERRAIN":
          if (check()) {
            layerManagement.addTerrainLayer(state.layerURL, state.isSct);
            addCallback(viewer.terrainProvider, "TERRAIN");
          }

          break;

        case "MVT":
          if (check()) {
            var mvtlayer = layerManagement.addMvtLayer(state.layerURL, state.layerName);
            addCallback(mvtlayer, "MVT");
          }

          break;
      }

      clearState();
    }

    function clearState() {
      state.layerURL = null;
      state.layerName = null;
      state.isAddToken = false;
      state.token = null;
      state.isSct = false;
    }

    function clear() {
      clearState();
      clearCallback();
    }

    return _objectSpread2(_objectSpread2({}, toRefs(state)), {}, {
      addLayer: addLayer,
      clear: clear
    });
  }
};

var _hoisted_1 = {
  id: "CustomService-panel",
  "class": "sm-panel"
};
var _hoisted_2 = {
  "class": "sm-function-module-sub-section",
  style: {
    "margin": "0"
  }
};
var _hoisted_3 = {
  "class": "sm-half-L"
};

var _hoisted_4 = /*#__PURE__*/createElementVNode("label", {
  style: {
    "width": "40%"
  }
}, "打开图层", -1
/* HOISTED */
);

var _hoisted_5 = /*#__PURE__*/createStaticVNode("<option value=\"SCENE\">场景</option><option value=\"S3M\">S3M</option><option value=\"IMG\">影像</option><option value=\"TERRAIN\">地形</option><option value=\"MVT\">矢量瓦片</option>", 5);

var _hoisted_10 = [_hoisted_5];
var _hoisted_11 = {
  "class": "sm-half-L flex-start"
};

var _hoisted_12 = /*#__PURE__*/createElementVNode("label", {
  "class": "label-S"
}, "添加token", -1
/* HOISTED */
);

var _hoisted_13 = {
  "class": "sm-half-L flex-start"
};

var _hoisted_14 = /*#__PURE__*/createElementVNode("label", {
  "class": "label-S"
}, "isSct", -1
/* HOISTED */
);

var _hoisted_15 = {
  "class": "boxchild"
};
function render(_ctx, _cache, $props, $setup, $data, $options) {
  var _directive_stopdrag = resolveDirective("stopdrag");

  var _directive_drag = resolveDirective("drag");

  return withDirectives((openBlock(), createElementBlock("div", _hoisted_1, [withDirectives((openBlock(), createElementBlock("div", _hoisted_2, [createElementVNode("div", _hoisted_3, [_hoisted_4, withDirectives(createElementVNode("select", {
    "class": "sm-select",
    style: {
      "width": "58%"
    },
    "onUpdate:modelValue": _cache[0] || (_cache[0] = function ($event) {
      return _ctx.layersType = $event;
    })
  }, _hoisted_10, 512
  /* NEED_PATCH */
  ), [[vModelSelect, _ctx.layersType]])]), createElementVNode("div", _hoisted_11, [withDirectives(createElementVNode("input", {
    type: "text",
    "class": "sm-input sm-margin-M",
    style: {
      "width": "100%"
    },
    placeholder: "URL",
    "onUpdate:modelValue": _cache[1] || (_cache[1] = function ($event) {
      return _ctx.layerURL = $event;
    })
  }, null, 512
  /* NEED_PATCH */
  ), [[vModelText, _ctx.layerURL]]), withDirectives(createElementVNode("input", {
    type: "text",
    "class": "sm-input sm-margin-M",
    style: {
      "width": "100%"
    },
    placeholder: "自定义名称",
    "onUpdate:modelValue": _cache[2] || (_cache[2] = function ($event) {
      return _ctx.layerName = $event;
    })
  }, null, 512
  /* NEED_PATCH */
  ), [[vModelText, _ctx.layerName]]), createCommentVNode(" v-show=\"layersType === 'S3M'\" "), _hoisted_12, withDirectives(createElementVNode("input", {
    checked: "",
    type: "checkbox",
    "onUpdate:modelValue": _cache[3] || (_cache[3] = function ($event) {
      return _ctx.isAddToken = $event;
    })
  }, null, 512
  /* NEED_PATCH */
  ), [[vModelCheckbox, _ctx.isAddToken]]), withDirectives(createElementVNode("input", {
    type: "text",
    "class": "sm-input sm-margin-M",
    style: {
      "width": "100%"
    },
    placeholder: "token",
    "onUpdate:modelValue": _cache[4] || (_cache[4] = function ($event) {
      return _ctx.token = $event;
    })
  }, null, 512
  /* NEED_PATCH */
  ), [[vModelText, _ctx.token], [vShow, _ctx.isAddToken]])]), withDirectives(createElementVNode("div", _hoisted_13, [_hoisted_14, withDirectives(createElementVNode("input", {
    checked: "",
    type: "checkbox",
    "onUpdate:modelValue": _cache[5] || (_cache[5] = function ($event) {
      return _ctx.isSct = $event;
    })
  }, null, 512
  /* NEED_PATCH */
  ), [[vModelCheckbox, _ctx.isSct]])], 512
  /* NEED_PATCH */
  ), [[vShow, _ctx.layersType === 'TERRAIN']]), createElementVNode("div", _hoisted_15, [createElementVNode("button", {
    "class": "tbtn tbtn-margin-left",
    type: "button",
    onClick: _cache[6] || (_cache[6] = function () {
      return $setup.addLayer && $setup.addLayer.apply($setup, arguments);
    })
  }, "添加"), createElementVNode("button", {
    onClick: _cache[7] || (_cache[7] = function () {
      return $setup.clear && $setup.clear.apply($setup, arguments);
    }),
    "class": "tbtn tbtn-margin-left",
    type: "button"
  }, "取消")])])), [[_directive_stopdrag]])])), [[_directive_drag]]);
}

script.render = render;
script.__file = "src/components/layer/custom-service/custom-service.vue";

script.install = function (app) {
  app.component(script.name, script);
};

export default script;
