import { reactive } from 'vue';

function _typeof(obj) {
  "@babel/helpers - typeof";

  if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
    _typeof = function (obj) {
      return typeof obj;
    };
  } else {
    _typeof = function (obj) {
      return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
    };
  }

  return _typeof(obj);
}

/** Used as the `TypeError` message for "Functions" methods. */
var FUNC_ERROR_TEXT = 'Expected a function';
/** Used as references for various `Number` constants. */

var NAN = 0 / 0;
/** `Object#toString` result references. */

var symbolTag = '[object Symbol]';
/** Used to match leading and trailing whitespace. */

var reTrim = /^\s+|\s+$/g;
/** Used to detect bad signed hexadecimal string values. */

var reIsBadHex = /^[-+]0x[0-9a-f]+$/i;
/** Used to detect binary string values. */

var reIsBinary = /^0b[01]+$/i;
/** Used to detect octal string values. */

var reIsOctal = /^0o[0-7]+$/i;
/** Built-in method references without a dependency on `root`. */

var freeParseInt = parseInt;
/** Detect free variable `global` from Node.js. */

var freeGlobal = (typeof global === "undefined" ? "undefined" : _typeof(global)) == 'object' && global && global.Object === Object && global;
/** Detect free variable `self`. */

var freeSelf = (typeof self === "undefined" ? "undefined" : _typeof(self)) == 'object' && self && self.Object === Object && self;
/** Used as a reference to the global object. */

var root = freeGlobal || freeSelf || Function('return this')();
/** Used for built-in method references. */

var objectProto = Object.prototype;
/**
 * Used to resolve the
 * [`toStringTag`](http://ecma-international.org/ecma-262/7.0/#sec-object.prototype.tostring)
 * of values.
 */

var objectToString = objectProto.toString;
/* Built-in method references for those with the same name as other `lodash` methods. */

var nativeMax = Math.max,
    nativeMin = Math.min;

var now = function now() {
  return root.Date.now();
};

function debounce(func, wait, options) {
  var lastArgs,
      lastThis,
      maxWait,
      result,
      timerId,
      lastCallTime,
      lastInvokeTime = 0,
      leading = false,
      maxing = false,
      trailing = true;

  if (typeof func != 'function') {
    throw new TypeError(FUNC_ERROR_TEXT);
  }

  wait = toNumber(wait) || 0;

  if (isObject(options)) {
    leading = !!options.leading;
    maxing = 'maxWait' in options;
    maxWait = maxing ? nativeMax(toNumber(options.maxWait) || 0, wait) : maxWait;
    trailing = 'trailing' in options ? !!options.trailing : trailing;
  }

  function invokeFunc(time) {
    var args = lastArgs,
        thisArg = lastThis;
    lastArgs = lastThis = undefined;
    lastInvokeTime = time;
    result = func.apply(thisArg, args);
    return result;
  }

  function leadingEdge(time) {
    // Reset any `maxWait` timer.
    lastInvokeTime = time; // Start the timer for the trailing edge.

    timerId = setTimeout(timerExpired, wait); // Invoke the leading edge.

    return leading ? invokeFunc(time) : result;
  }

  function remainingWait(time) {
    var timeSinceLastCall = time - lastCallTime,
        timeSinceLastInvoke = time - lastInvokeTime,
        result = wait - timeSinceLastCall;
    return maxing ? nativeMin(result, maxWait - timeSinceLastInvoke) : result;
  }

  function shouldInvoke(time) {
    var timeSinceLastCall = time - lastCallTime,
        timeSinceLastInvoke = time - lastInvokeTime; // Either this is the first call, activity has stopped and we're at the
    // trailing edge, the system time has gone backwards and we're treating
    // it as the trailing edge, or we've hit the `maxWait` limit.

    return lastCallTime === undefined || timeSinceLastCall >= wait || timeSinceLastCall < 0 || maxing && timeSinceLastInvoke >= maxWait;
  }

  function timerExpired() {
    var time = now();

    if (shouldInvoke(time)) {
      return trailingEdge(time);
    } // Restart the timer.


    timerId = setTimeout(timerExpired, remainingWait(time));
  }

  function trailingEdge(time) {
    timerId = undefined; // Only invoke if we have `lastArgs` which means `func` has been
    // debounced at least once.

    if (trailing && lastArgs) {
      return invokeFunc(time);
    }

    lastArgs = lastThis = undefined;
    return result;
  }

  function cancel() {
    if (timerId !== undefined) {
      clearTimeout(timerId);
    }

    lastInvokeTime = 0;
    lastArgs = lastCallTime = lastThis = timerId = undefined;
  }

  function flush() {
    return timerId === undefined ? result : trailingEdge(now());
  }

  function debounced() {
    var time = now(),
        isInvoking = shouldInvoke(time);
    lastArgs = arguments;
    lastThis = this;
    lastCallTime = time;

    if (isInvoking) {
      if (timerId === undefined) {
        return leadingEdge(lastCallTime);
      }

      if (maxing) {
        // Handle invocations in a tight loop.
        timerId = setTimeout(timerExpired, wait);
        return invokeFunc(lastCallTime);
      }
    }

    if (timerId === undefined) {
      timerId = setTimeout(timerExpired, wait);
    }

    return result;
  }

  debounced.cancel = cancel;
  debounced.flush = flush;
  return debounced;
}

function isObject(value) {
  var type = _typeof(value);

  return !!value && (type == 'object' || type == 'function');
}

function isObjectLike(value) {
  return !!value && _typeof(value) == 'object';
}

function isSymbol(value) {
  return _typeof(value) == 'symbol' || isObjectLike(value) && objectToString.call(value) == symbolTag;
}

function toNumber(value) {
  if (typeof value == 'number') {
    return value;
  }

  if (isSymbol(value)) {
    return NAN;
  }

  if (isObject(value)) {
    var other = typeof value.valueOf == 'function' ? value.valueOf() : value;
    value = isObject(other) ? other + '' : other;
  }

  if (typeof value != 'string') {
    return value === 0 ? value : +value;
  }

  value = value.replace(reTrim, '');
  var isBinary = reIsBinary.test(value);
  return isBinary || reIsOctal.test(value) ? freeParseInt(value.slice(2), isBinary ? 2 : 8) : reIsBadHex.test(value) ? NAN : +value;
}

// 创建一个简单的store状态管理

var storeState = reactive({
  isViewer: false,
  //viewer初始化标志
  changeLayers: 0,
  //图层改变加载完毕监听
  changeGeometrys: 0 //三维分析体改变标志

});
var actions = {
  setIsViewer: function setIsViewer(newValue) {
    storeState.isViewer = newValue;
  },
  setChangeLayers: function setChangeLayers(newValue) {
    storeState.changeLayers += 1;
  },
  setGeometrys: function setGeometrys(newValue) {
    storeState.changeGeometrys += 1;
  }
}; // 全局公共数据

var storeDate = {
  geometrys: {},
  //存储当前存在的三位空间查询体：如天际线体，可视域体
  layers: null
};
var store = {
  storeState: storeState,
  actions: actions,
  storeDate: storeDate
};

function drag (app, isDrag) {
  app.config.globalProperties.store = store;
  app.directive('drag', {
    mounted: function mounted(a, binding) {
      // if(isDrag === false || isDrag === 'false'){
      //   return;
      // }
      var isStart = false; // 是否已经开始拖拽

      var l, t, x, y; // 当前被拖动的距离

      var w; // 当前屏幕宽度

      var h; // 当前屏幕的高度 // 移动端

      var dragElem = a;

      dragElem.addEventListener('touchstart', function (e) {
        isStart = true; // 如果没有开始拖拽， 则可以拖拽

        if (!e.changedTouches[0]) return;
        var _e$changedTouches$ = e.changedTouches[0],
            clientX = _e$changedTouches$.clientX,
            clientY = _e$changedTouches$.clientY;
        x = clientX - e.changedTouches[0].target.x;
        y = clientY - e.changedTouches[0].target.y;
        w = document.body.clientWidth; // 当前屏幕宽度

        h = document.body.clientHeight; // 当前屏幕的高度
      }, {
        passive: false
      });

      dragElem.addEventListener('touchmove', debounce(function (e) {
        e.preventDefault();
        l = e.changedTouches[0].clientX - x;
        t = e.changedTouches[0].clientY - y;

        if (l < 0 && t < 0) {
          a.style.left = 0 + 'px';
          a.style.top = 0 + 'px';
        } else if (l < 0 && t + a.clientHeight < h) {
          a.style.left = 0 + 'px';
          a.style.top = t + 'px';
        } else if (l < 0 && t + a.clientHeight >= h) {
          a.style.left = 0 + 'px';
          a.style.top = h - a.clientHeight + 'px';
        } else if (l + a.clientWidth > w && t < 0) {
          a.style.left = w - a.clientWidth + 'px';
          a.style.top = 0 + 'px';
        } else if (l + a.clientWidth < w && t + a.clientHeight >= h) {
          a.style.left = l + 'px';
          a.style.top = h - a.clientHeight + 'px';
        } else if (l + a.clientWidth < w && t < 0) {
          a.style.left = l + 'px';
          a.style.top = 0 + 'px';
        } else if (l + a.clientWidth > w && t + a.clientHeight < h) {
          a.style.left = w - a.clientWidth + 'px';
          a.style.top = t + 'px';
        } else if (l + a.clientWidth > w && t + a.clientHeight >= h) {
          a.style.left = w - a.clientWidth + 'px';
          a.style.top = h - a.clientHeight + 'px';
        } else {
          a.style.left = l + 'px';
          a.style.top = t + 'px';
        }
      }, 5), {
        passive: false
      });
      dragElem.addEventListener('touchend', function (e) {
        isStart = false;
        document.ontouchmove = null;
        document.ontouchmove = null;
        ({
          type: 'move',
          clientX: x - e.changedTouches[0].clientX,
          // 拖动的 x 距离
          clientY: y - e.changedTouches[0].clientY // 拖动的 y 距离

        }); // binding.value(distance) // 返回拖动的距离
      }, {
        passive: false
      });

      dragElem.onmousedown = function (e) {
        // e.stopPropagation();
        // e.preventDefault()
        // dragElem.setAttribute('data-flag', false) //防止拖动时触发点击事件
        // firstTime = new Date().getTime();
        w = document.body.clientWidth; // 当前屏幕宽度

        h = document.body.clientHeight; // 当前屏幕的高度

        if (isStart) return; // 如果已经开始拖拽， 返回

        isStart = true; // 如果没有开始拖拽， 则可以拖拽

        var clientX = e.clientX,
            clientY = e.clientY;
        var x = clientX - a.offsetLeft;
        var y = clientY - a.offsetTop;
        document.onmousemove = debounce(function (e) {
          // e.preventDefault()
          // e.stopPropagation();
          l = e.clientX - x;
          t = e.clientY - y;
          console.log('onmousemove', l, t);

          if (l < 0 && t < 0) {
            a.style.left = 0 + 'px';
            a.style.top = 0 + 'px';
          } else if (l < 0 && t + a.clientHeight < h) {
            a.style.left = 0 + 'px';
            a.style.top = t + 'px';
          } else if (l < 0 && t + a.clientHeight >= h) {
            a.style.left = 0 + 'px';
            a.style.top = h - a.clientHeight + 'px';
          } else if (l + a.clientWidth > w && t < 0) {
            a.style.left = w - a.clientWidth + 'px';
            a.style.top = 0 + 'px';
          } else if (l + a.clientWidth < w && t + a.clientHeight >= h) {
            a.style.left = l + 'px';
            a.style.top = h - a.clientHeight + 'px';
          } else if (l + a.clientWidth < w && t < 0) {
            a.style.left = l + 'px';
            a.style.top = 0 + 'px';
          } else if (l + a.clientWidth > w && t + a.clientHeight < h) {
            a.style.left = w - a.clientWidth + 'px';
            a.style.top = t + 'px';
          } else if (l + a.clientWidth > w && t + a.clientHeight >= h) {
            a.style.left = w - a.clientWidth + 'px';
            a.style.top = h - a.clientHeight + 'px';
          } else {
            a.style.left = l + 'px';
            a.style.top = t + 'px';
          }
        }, 5);

        document.onmouseup = function (e) {
          document.onmousedown = null;
          document.onmousemove = null;
          isStart = false;
          console.log('onmouseup'); // onmouseup 时的时间，并计算差值
          // lastTime = new Date().getTime();
          // if ((lastTime - firstTime) < 200) {
          //   dragElem.setAttribute('data-flag', true)
          // }
          // distance = {
          //   type: 'move',
          //   clientX: clientX - e.clientX, // 拖动的 x 距离
          //   clientY: clientY - e.clientY // 拖动的 y 距离
          // }
          // binding.value(distance) // 返回拖动的距离
        };
      };
    }
  });
  /*阻止拖拽*/

  app.directive('stopdrag', {
    beforeMount: function beforeMount(a, binding) {
      a.onmousedown = function (e) {
        // if (e.target.className == 'el-input__inner') return;
        e.stopPropagation();
      };
    }
  });
}

export default drag;
