import { reactive, toRefs, ref, watch, onMounted, onBeforeUnmount, resolveComponent, resolveDirective, openBlock, createElementBlock, Fragment, withDirectives, createElementVNode, createVNode, createCommentVNode, toDisplayString } from 'vue';

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    if (enumerableOnly) symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    });
    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(Object(source), true).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(Object(source)).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

var ResourceCN = {
  showRenderLoopErrors: '渲染时发生错误，已停止渲染。',
  AttributeError: '该组件props没有这个属性：',
  NoPickPositionSupported: "不支持深度纹理,无法绘制多边形，地形操作功能无法使用！",
  NoTerrain: "请在地形里使用地形组件！",
  initViewerWarn: '请先初始化viewer!',
  MoveMouseHeightBox: '点击鼠标左键结束矩形绘制，移动鼠标绘制box高度',
  RightClickEndDrawing: '右键单击结束绘制',
  LeftClickBottomBox: '点击鼠标左键，开始绘制矩形作为box底面',
  ClickModelAddBox: '点击模型，添加裁剪盒子',
  SkyLineWarn: "获取天际线体前，请先绘制天际线！",
  SkyLineBody: '天际线体',
  ShadowqueryWarn: "此操作需要先开启阴影！",
  VeiwshedBody: '可视体',
  VeiwshedBodyHidden: '不可视体',
  EchartsErr: "二维显示需要echarts支持，未找到相关依赖！",
  BaseMapImg: '底图',
  tip1: '<p>点击左键确定操作区域中间点</p><p>右键单击结束绘制</p>'
};

// 组件内部的语言资源：主要包括提示信息
var currentLanguage, Resource;
var cookieLanguage = getLang().toLowerCase();

function getLang() {
  //浏览器语言  IE用browserLanguage，非IE使用language进行判断
  var lang = (navigator.language || navigator.browserLanguage).toLowerCase();
  window.lang = lang; //判断portal设置语言 通过cookie获取
  //   const cookies = document.cookie.split(';');
  //   if (cookies.length > 0) {
  //     cookies.forEach(function (cookie) {
  //       const arr = cookie.split('=');
  //       if (arr[0].toLowerCase().trim() === 'language') {
  //         lang = arr[1];
  //         return;
  //       }
  //     });
  //   }

  return lang;
}

if (cookieLanguage !== undefined) {
  currentLanguage = cookieLanguage;
} else {
  currentLanguage = (navigator.language || navigator.browserLanguage).toLowerCase(); // 获取当前浏览器的语言
}

if (currentLanguage.startsWith('zh')) {
  Resource = ResourceCN;
} else if (currentLanguage.startsWith('ja')) {
  Resource = ResourceCN;
} else {
  Resource = ResourceCN;
}

var resource = Resource;

// 创建一个简单的store状态管理

var storeState = reactive({
  isViewer: false,
  //viewer初始化标志
  changeLayers: 0,
  //图层改变加载完毕监听
  changeGeometrys: 0 //三维分析体改变标志

});
var actions = {
  setIsViewer: function setIsViewer(newValue) {
    storeState.isViewer = newValue;
  },
  setChangeLayers: function setChangeLayers(newValue) {
    storeState.changeLayers += 1;
  },
  setGeometrys: function setGeometrys(newValue) {
    storeState.changeGeometrys += 1;
  }
}; // 全局公共数据

function layerManage(props) {
  // 设置默认值数据
  var state = reactive({
    TreeDatas: [],
    expandedKeys: []
  }); // 初始化数据

  var layers, imgLayers, terrainLayers, mvtLayers, terrainProvider;
  var dom, wide, heide;
  var tree = ref(null);
  var node_rightClick,
      domContextmenu = ref(null); //保存右键选中的节点

  var deleteCallback = function deleteCallback() {}; //右键删除图层的回调函数初始化


  if (props && props.deleteCallback) {
    deleteCallback = props.deleteCallback;
  } //监听图层加载完成


  watch(function () {
    return storeState.changeLayers;
  }, function (val) {
    initLayers();
  });
  onMounted(function () {
    setTimeout(function () {
      initLayers();
    }, 500);
  }); //初始化图层

  function initLayers() {
    dom = document.getElementById('cesiumContainer');
    wide = document.body.clientWidth - dom.clientWidth; //定位矫正

    heide = document.body.clientHeight - dom.clientHeight;
    layers = viewer.scene.layers.layerQueue;
    imgLayers = viewer.imageryLayers._layers;
    mvtLayers = viewer.scene._vectorTileMaps._layerQueue;
    terrainLayers = viewer.terrainProvider;
    state.TreeDatas.length = 0;
    updataS3MLayer();
    updataImgLayers();
    updataMvtLayers();
    updataTerrainLayers();
    setTimeout(function () {
      tree.value.setCheckedNodes(state.TreeDatas);
    }, 500);
    console.log(mvtLayers);
  } // 分析
  // updatS3M图层


  function updataS3MLayer() {
    if (layers.length == 0) {
      if (state.TreeDatas[0]) tree.value.remove(state.TreeDatas[0]);
      return;
    }

    var S3MLayersObj = {
      id: 's3m',
      label: "S3M图层",
      children: []
    };
    layers.forEach(function (layer, index) {
      var S3Mlayer = {
        id: 's3m-' + index,
        label: layer._name
      };
      S3MLayersObj.children.push(S3Mlayer);
    });
    state.TreeDatas[0] = S3MLayersObj;
  } //updatImg


  function updataImgLayers() {
    if (imgLayers.length == 1) {
      if (state.TreeDatas[1]) tree.value.remove(state.TreeDatas[1]);
      return;
    }

    var imgLayersObj = {
      id: 'img',
      label: "IMG图层",
      children: []
    };
    imgLayers.forEach(function (layer, index) {
      var isMvt = layer._imageryProvider instanceof Cesium.MvtProviderGL;
      if (index === 0 || isMvt) return true;
      var IMGlayer = {
        id: 'img-' + index,
        label: resource.BaseMapImg
      };

      if (layer._imageryProvider.tablename) {
        IMGlayer.label = layer._imageryProvider.tablename;
      }

      imgLayersObj.children.unshift(IMGlayer);
    });
    if (imgLayersObj.children.length > 0) state.TreeDatas[1] = imgLayersObj;
  } //updatMVT


  function updataMvtLayers() {
    if (mvtLayers.length == 0) {
      if (state.TreeDatas[2]) tree.value.remove(state.TreeDatas[2]);
      return;
    }

    var mvtLayersObj = {
      id: 'mvt',
      label: "MVT图层",
      children: []
    };
    mvtLayers.forEach(function (layer, index) {
      var IMGlayer = {
        id: 'mvt-' + index,
        label: layer.name
      };
      mvtLayersObj.children.unshift(IMGlayer);
    });
    state.TreeDatas[2] = mvtLayersObj;
  } //updatTerrain


  function updataTerrainLayers() {
    if (!terrainLayers.tablename) {
      return;
    }

    var terrainLayersObj = {
      id: 'terrain',
      label: "地形图层",
      children: []
    };
    var TerrainLayer = {
      id: 'terrain-0',
      label: terrainLayers.tablename
    };
    terrainLayersObj.children.push(TerrainLayer);
    state.TreeDatas[3] = terrainLayersObj;
  } //勾选节点函数


  function checkNode(data) {
    var node = tree.value.getNode(data);
    var ids = data.id.split('-');
    setVisible(ids, node.checked);
  } //设置图层显隐


  function setVisible(ids, checked) {
    var type = ids[0];
    var index = ids[1];

    switch (type) {
      case 's3m':
        if (!index) {
          for (var i = 0; i < layers.length; i++) {
            layers[i].visible = checked;
          }

          return;
        }

        layers[index].visible = checked;
        break;

      case 'img':
        if (!index) {
          for (var _i = 1; _i < imgLayers.length; _i++) {
            imgLayers[_i].show = checked;
          }

          return;
        }

        imgLayers[index].show = checked;
        break;

      case 'mvt':
        if (!index) {
          for (var _i2 = 0; _i2 < mvtLayers.length; _i2++) {
            mvtLayers[_i2].show = checked;
          }

          return;
        }

        mvtLayers[index].show = checked;
        break;

      case 'terrain':
        if (!checked) {
          terrainProvider = viewer.terrainProvider;
          viewer.terrainProvider = new Cesium.EllipsoidTerrainProvider();
        } else {
          viewer.terrainProvider = terrainProvider;
        }

        break;
    }
  }

  function nodeClick(data) {
    var ids = data.id.split('-');
    flytoLayer(ids);
  } //定位飞向指定图层


  function flytoLayer(ids) {
    var type = ids[0];
    var index = ids[1];
    var layer;

    switch (type) {
      case 's3m':
        if (index) layer = layers[index];
        break;

      case 'img':
        if (index) layer = imgLayers[index];
        break;

      case 'mvt':
        if (index) layer = mvtLayers[index];
        break;
    }

    if (layer) viewer.flyTo(layer);
  }

  function nodeContextmenu(event, data) {
    var ids = data.id.split('-');
    if (!ids[1]) return;
    node_rightClick = data;
    domContextmenu.value.style.left = event.clientX + 30 - wide + 'px';
    if (event.clientX >= 1810) domContextmenu.value.style.left = event.clientX - 80 - wide + 'px';
    domContextmenu.value.style.top = event.clientY - heide + 'px';
    domContextmenu.value.style.display = 'block';
  } // 点击任意隐藏右键弹出的操作框


  document.onclick = function (e) {
    e.stopPropagation();
    domContextmenu.value.style.display = 'none';
  }; // 删除图层函数


  function deleteLayer() {
    domContextmenu.value.style.display = 'none';
    var ids = node_rightClick.id.split('-');
    var type = ids[0];
    var index = ids[1];

    switch (type) {
      case 's3m':
        if (index) {
          // layers[index].destroy();
          viewer.scene.layers.remove(layers[index]._name);
          updataS3MLayer();
          setTimeout(function () {
            state.expandedKeys = ['s3m'];
            tree.value.setCheckedNodes(state.TreeDatas);
          }, 50);
        }
        break;

      case 'img':
        if (index) {
          // imgLayers[index].destroy();
          viewer.imageryLayers.remove(imgLayers[index]);
          updataImgLayers();
          setTimeout(function () {
            tree.value.setCheckedNodes(state.TreeDatas);
          }, 50);
        }
        break;

      case 'mvt':
        if (index) {
          // mvtLayers[index].destroy();
          viewer.scene.removeVectorTilesMap(mvtLayers[index].name);
          updataMvtLayers();
          setTimeout(function () {
            tree.value.setCheckedNodes(state.TreeDatas);
          }, 100);
        }
        break;

      case 'terrain':
        viewer.terrainProvider = new Cesium.EllipsoidTerrainProvider();
        terrainProvider = null;
        var node = tree.value.getNode(type);
        tree.value.remove(node);
        break;
    }
    actions.setChangeLayers();
    deleteCallback(node_rightClick); //删除图层回调，用于外部在图层删除后的操作
  } // 销毁


  onBeforeUnmount(function () {
    document.onclick = function () {};
  });
  return _objectSpread2(_objectSpread2({}, toRefs(state)), {}, {
    tree: tree,
    domContextmenu: domContextmenu,
    checkNode: checkNode,
    nodeContextmenu: nodeContextmenu,
    nodeClick: nodeClick,
    deleteLayer: deleteLayer
  });
}

var script = {
  name: "Sm3dLayerManage",
  props: {
    //删除图层回调，返回删除的树节点
    deleteCallback: {
      type: Function
    }
  },
  setup: function setup(props) {
    var _management = layerManage(props),
        nodeContextmenu = _management.nodeContextmenu,
        nodeClick = _management.nodeClick,
        TreeDatas = _management.TreeDatas,
        tree = _management.tree,
        domContextmenu = _management.domContextmenu,
        checkNode = _management.checkNode,
        deleteLayer = _management.deleteLayer,
        expandedKeys = _management.expandedKeys;

    return {
      nodeContextmenu: nodeContextmenu,
      nodeClick: nodeClick,
      TreeDatas: TreeDatas,
      tree: tree,
      domContextmenu: domContextmenu,
      checkNode: checkNode,
      deleteLayer: deleteLayer,
      expandedKeys: expandedKeys
    };
  }
};

var _hoisted_1 = {
  id: "layer-manage-panel",
  "class": "sm-panel"
};
var _hoisted_2 = {
  "class": "sm-function-module-sub-section",
  style: {
    "margin": "0"
  }
};
var _hoisted_3 = {
  "class": "sm-half-L"
};
var _hoisted_4 = {
  id: "contextmenu",
  ref: "domContextmenu"
};
function render(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_el_tree = resolveComponent("el-tree");

  var _directive_stopdrag = resolveDirective("stopdrag");

  var _directive_drag = resolveDirective("drag");

  return openBlock(), createElementBlock(Fragment, null, [withDirectives((openBlock(), createElementBlock("div", _hoisted_1, [withDirectives((openBlock(), createElementBlock("div", _hoisted_2, [createElementVNode("div", _hoisted_3, [createVNode(_component_el_tree, {
    data: $setup.TreeDatas,
    "show-checkbox": "",
    "node-key": "id",
    accordion: "",
    ref: "tree",
    "default-expanded-keys": $setup.expandedKeys,
    "highlight-current": true,
    onCheck: $setup.checkNode,
    onNodeContextmenu: $setup.nodeContextmenu,
    onNodeClick: $setup.nodeClick
  }, null, 8
  /* PROPS */
  , ["data", "default-expanded-keys", "onCheck", "onNodeContextmenu", "onNodeClick"])])])), [[_directive_stopdrag]])])), [[_directive_drag]]), createElementVNode("div", _hoisted_4, [createCommentVNode(" <span>图层属性</span><br>\r\n          <span>图层风格</span><br>\r\n    <span>图层操作</span><br>"), createElementVNode("span", {
    onClick: _cache[0] || (_cache[0] = function () {
      return $setup.deleteLayer && $setup.deleteLayer.apply($setup, arguments);
    }),
    style: {
      "color": "red"
    }
  }, toDisplayString(_ctx.Resource["delete"]), 1
  /* TEXT */
  )], 512
  /* NEED_PATCH */
  )], 64
  /* STABLE_FRAGMENT */
  );
}

script.render = render;
script.__file = "src/components/layer/layer-manage/layer-manage.vue";

script.install = function (app) {
  app.component(script.name, script);
};

export default script;
