import { toRefs, reactive, watch, onBeforeUnmount, resolveComponent, resolveDirective, withDirectives, openBlock, createElementBlock, createElementVNode, toDisplayString, createVNode, vModelText } from 'vue';

function _typeof(obj) {
  "@babel/helpers - typeof";

  if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
    _typeof = function (obj) {
      return typeof obj;
    };
  } else {
    _typeof = function (obj) {
      return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
    };
  }

  return _typeof(obj);
}

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    if (enumerableOnly) symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    });
    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(Object(source), true).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(Object(source)).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

function _toConsumableArray(arr) {
  return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread();
}

function _arrayWithoutHoles(arr) {
  if (Array.isArray(arr)) return _arrayLikeToArray(arr);
}

function _iterableToArray(iter) {
  if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter);
}

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}

function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;

  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

  return arr2;
}

function _nonIterableSpread() {
  throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

//随鼠标移动消息提示工具
function createTooltip(frameDiv) {
  var tooltip = function tooltip(frameDiv) {
    var div = document.createElement("DIV");
    div.className = "twipsy right";
    var arrow = document.createElement("DIV");
    arrow.className = "twipsy-arrow";
    div.appendChild(arrow);
    var title = document.createElement("DIV");
    title.className = "twipsy-inner";
    div.appendChild(title);
    this._div = div;
    this._title = title;
    this.message = "";
    frameDiv.appendChild(div);
    var that = this;

    div.onmousemove = function (evt) {
      that.showAt({
        x: evt.clientX,
        y: evt.clientY
      }, that.message);
    };
  };

  tooltip.prototype.setVisible = function (visible) {
    this._div.style.display = visible ? "block" : "none";
  };

  tooltip.prototype.showAt = function (position, message) {
    if (position && message) {
      this.setVisible(true);
      this._title.innerHTML = message;
      this._div.style.left = position.x + 10 + "px";
      this._div.style.top = position.y - this._div.clientHeight / 2 + "px";
      this.message = message;
    }
  };

  return new tooltip(frameDiv);
}

/*
* 常用工具类
*/
//axios本版本不支持jsonp
var axiosJsonp = function axiosJsonp(url) {
  if (!url) {
    console.error('Axios.JSONP 至少需要一个url参数!');
    return;
  }

  return new Promise(function (resolve, reject) {
    window.jsonCallBack = function (result) {
      resolve(result);
    };

    var JSONP = document.createElement("script");
    JSONP.type = "text/javascript";
    JSONP.src = "".concat(url, "&callback=jsonCallBack");
    document.getElementsByTagName("head")[0].appendChild(JSONP);
    setTimeout(function () {
      document.getElementsByTagName("head")[0].removeChild(JSONP);
    }, 500);
  });
}; //判断两数组或对象相等


var isEqualArr = function isEqualArr(arg1, arg2) {
  if (!arg1 || !arg2) return true;
  var bol = true;

  if (Object.keys(arg1).length != Object.keys(arg2).length) {
    return false;
  }

  for (var key in arg1) {
    if (_typeof(arg1[key]) == 'object') {
      bol = isSame(arg1[key], arg2[key]);

      if (!bol) {
        break;
      }
    } else if (arg1[key] != arg2[key]) {
      bol = false;
      break;
    }
  }

  return bol;
}; //坐标转化
//笛卡尔转经纬度


var CartesiantoDegrees = function CartesiantoDegrees(Cartesians) {
  var array = [].concat(Cartesians);
  var positions = [];

  for (var i = 0, len = array.length; i < len; i++) {
    var cartographic = Cesium.Cartographic.fromCartesian(array[i]);
    var longitude = Cesium.Math.toDegrees(cartographic.longitude);
    var latitude = Cesium.Math.toDegrees(cartographic.latitude);
    var h = cartographic.height;

    if (positions.indexOf(longitude) == -1 && positions.indexOf(latitude) == -1) {
      positions.push(longitude);
      positions.push(latitude);
      positions.push(h);
    }
  }

  return positions;
}; //笛卡尔转经纬度(每个点是独立的对象)


var CartesiantoDegreesObjs = function CartesiantoDegreesObjs(Cartesians) {
  var array = [].concat(Cartesians);
  var positions = [];

  for (var i = 0, len = array.length; i < len; i++) {
    var cartographic = Cesium.Cartographic.fromCartesian(array[i]);
    var obj = {
      longitude: Cesium.Math.toDegrees(cartographic.longitude),
      latitude: Cesium.Math.toDegrees(cartographic.latitude),
      height: cartographic.height
    };
    positions.push(obj);
  }

  return positions;
}; // 弧度转经纬度


var CartographictoDegrees = function CartographictoDegrees(wgsPosition) {
  var longitude = Cesium.Math.toDegrees(wgsPosition.longitude);
  var latitude = Cesium.Math.toDegrees(wgsPosition.latitude);
  var height = wgsPosition.height;
  return [longitude, latitude, height];
}; //去重函数  数组


var unique = function unique(arr) {
  var res = [];
  var json = {};

  for (var i = 0; i < arr.length; i++) {
    if (!json[arr[i]]) {
      res.push(arr[i]);
      json[arr[i]] = 1;
    }
  }

  return res;
}; // 获取渐变色函数


function gradientColors(start, end, steps, gamma) {
  var i,
      j,
      ms,
      me,
      output = [],
      so = [];
  gamma = gamma || 1;

  var normalize = function normalize(channel) {
    return Math.pow(channel / 255, gamma);
  };

  start = parseColor(start).map(normalize);
  end = parseColor(end).map(normalize);

  for (i = 0; i < steps; i++) {
    ms = i / (steps - 1);
    me = 1 - ms;

    for (j = 0; j < 3; j++) {
      so[j] = pad(Math.round(Math.pow(start[j] * me + end[j] * ms, 1 / gamma) * 255).toString(16));
    }

    output.push('#' + so.join(''));
  }

  return output;

  function parseColor(hexStr) {
    return hexStr.length === 4 ? hexStr.substr(1).split('').map(function (s) {
      return 0x11 * parseInt(s, 16);
    }) : [hexStr.substr(1, 2), hexStr.substr(3, 2), hexStr.substr(5, 2)].map(function (s) {
      return parseInt(s, 16);
    });
  }

  function pad(s) {
    return s.length === 1 ? '0' + s : s;
  }
}

function getAngleAndRadian(pointA, pointB) {
  //建立以点A为原点，X轴为east,Y轴为north,Z轴朝上的坐标系
  var transform = Cesium.Transforms.eastNorthUpToFixedFrame(pointA); //向量AB

  var positionvector = Cesium.Cartesian3.subtract(pointB, pointA, new Cesium.Cartesian3()); //因transform是将A为原点的eastNorthUp坐标系中的点转换到世界坐标系的矩阵
  //AB为世界坐标中的向量
  //因此将AB向量转换为A原点坐标系中的向量，需乘以transform的逆矩阵。

  var vector = Cesium.Matrix4.multiplyByPointAsVector(Cesium.Matrix4.inverse(transform, new Cesium.Matrix4()), positionvector, new Cesium.Cartesian3()); //归一化

  var direction = Cesium.Cartesian3.normalize(vector, new Cesium.Cartesian3()); //heading

  var heading1 = Math.atan2(direction.y, direction.x) - Cesium.Math.PI_OVER_TWO;
  var radian = Cesium.Math.TWO_PI - Cesium.Math.zeroToTwoPi(heading1);
  var angle = radian * (180 / Math.PI);

  if (angle < 0) {
    angle = angle + 360;
  }

  return {
    angle: angle,
    radian: radian
  };
}

function getPitch(pointA, pointB) {
  var transfrom = Cesium.Transforms.eastNorthUpToFixedFrame(pointA);
  var vector = Cesium.Cartesian3.subtract(pointB, pointA, new Cesium.Cartesian3());
  var direction = Cesium.Matrix4.multiplyByPointAsVector(Cesium.Matrix4.inverse(transfrom, transfrom), vector, vector);
  Cesium.Cartesian3.normalize(direction, direction); //因为direction已归一化，斜边长度等于1，所以余弦函数等于direction.z

  var radian = Cesium.Math.PI_OVER_TWO - Cesium.Math.acosClamped(direction.z);
  var angle = radian * (180 / Math.PI);

  if (angle < 0) {
    angle = angle + 360;
  }

  return {
    angle: angle,
    radian: radian
  };
}

var tool = {
  axiosJsonp: axiosJsonp,
  isEqualArr: isEqualArr,
  CartesiantoDegrees: CartesiantoDegrees,
  CartesiantoDegreesObjs: CartesiantoDegreesObjs,
  unique: unique,
  gradientColors: gradientColors,
  getAngleAndRadian: getAngleAndRadian,
  CartographictoDegrees: CartographictoDegrees,
  getPitch: getPitch
};

var ResourceCN = {
  showRenderLoopErrors: '渲染时发生错误，已停止渲染。',
  AttributeError: '该组件props没有这个属性：',
  NoPickPositionSupported: "不支持深度纹理,无法绘制多边形，地形操作功能无法使用！",
  NoTerrain: "请在地形里使用地形组件！",
  initViewerWarn: '请先初始化viewer!',
  MoveMouseHeightBox: '点击鼠标左键结束矩形绘制，移动鼠标绘制box高度',
  RightClickEndDrawing: '右键单击结束绘制',
  LeftClickBottomBox: '点击鼠标左键，开始绘制矩形作为box底面',
  ClickModelAddBox: '点击模型，添加裁剪盒子',
  SkyLineWarn: "获取天际线体前，请先绘制天际线！",
  SkyLineBody: '天际线体',
  ShadowqueryWarn: "此操作需要先开启阴影！",
  VeiwshedBody: '可视体',
  VeiwshedBodyHidden: '不可视体',
  EchartsErr: "二维显示需要echarts支持，未找到相关依赖！",
  BaseMapImg: '底图',
  tip1: '<p>点击左键确定操作区域中间点</p><p>右键单击结束绘制</p>'
};

// 组件内部的语言资源：主要包括提示信息
var currentLanguage, Resource;
var cookieLanguage = getLang().toLowerCase();

function getLang() {
  //浏览器语言  IE用browserLanguage，非IE使用language进行判断
  var lang = (navigator.language || navigator.browserLanguage).toLowerCase();
  window.lang = lang; //判断portal设置语言 通过cookie获取
  //   const cookies = document.cookie.split(';');
  //   if (cookies.length > 0) {
  //     cookies.forEach(function (cookie) {
  //       const arr = cookie.split('=');
  //       if (arr[0].toLowerCase().trim() === 'language') {
  //         lang = arr[1];
  //         return;
  //       }
  //     });
  //   }

  return lang;
}

if (cookieLanguage !== undefined) {
  currentLanguage = cookieLanguage;
} else {
  currentLanguage = (navigator.language || navigator.browserLanguage).toLowerCase(); // 获取当前浏览器的语言
}

if (currentLanguage.startsWith('zh')) {
  Resource = ResourceCN;
} else if (currentLanguage.startsWith('ja')) {
  Resource = ResourceCN;
} else {
  Resource = ResourceCN;
}

var resource = Resource;

/**
 * 初始化
 * DrawMode：类型
 * clampMode：模式
 */

var initHandler = function initHandler(DrawMode, clampMode) {
  var clampmode = 0;

  if (clampMode) {
    clampmode = clampMode;
  }

  switch (DrawMode) {
    case "Point":
      window.handlerPoint = new Cesium.DrawHandler(viewer, Cesium.DrawMode.Point);
      break;

    case "Polyline":
      window.handlerPolyline = new Cesium.DrawHandler(viewer, Cesium.DrawMode.Line, clampmode);
      break;

    case "Polygon":
      window.handlerPolygon = new Cesium.DrawHandler(viewer, Cesium.DrawMode.Polygon, clampmode);
      break;

    case "Marker":
      window.handlerMarker = new Cesium.DrawHandler(viewer, Cesium.DrawMode.Marker, clampmode);
      break;

    case "Box":
      window.handlerBox = new Cesium.DrawHandler(viewer, Cesium.DrawMode.Box, clampmode);
      break;
  }

  if (!window.tooltip) {
    window.tooltip = createTooltip(viewer._element);
  } // 半透线创建


  if (!window.polylineCollection) {
    window.polylineCollection = new Cesium.PolylineCollection({
      translucentRS: Cesium.RenderState.fromCache({
        depthMask: false,
        depthTest: {
          enabled: false
        }
      })
    });
    window.polylineTransparent = window.polylineCollection.add({
      width: 2,
      material: Cesium.Material.fromType(Cesium.Material.ColorType, {
        color: Cesium.Color.fromCssColorString("#51ff00").withAlpha(0.3)
      })
    });
    viewer.scene.primitives.add(window.polylineCollection);
  }
};
/**
 * 绘制
 * PolyType：类型 
 * lineVisib：绘制时是否显示绘制线（boolean）
 * toolTipObj：绘制时提示内容{beforeDrawing：绘制开始前提示(string)，isDrawing：正在绘制时提示,即绘制过程中（string）}
 */


var handlerDrawing = function handlerDrawing(PolyType, lineVisib, toolTipObj) {
  var lineVisible = true;

  if (lineVisib === false) {
    lineVisible = lineVisib;
  }

  var DrawHandler = judgeDrawHandlerType(PolyType); //获取操作对象

  return new Promise(function (resolve, reject) {
    //做一些异步操作
    var tooltip = window.tooltip;
    var clearActFn = DrawHandler.activeEvt.addEventListener(function (isActive) {
      if (isActive == true) {
        viewer.enableCursorStyle = false;
        viewer._element.style.cursor = '';

        if (PolyType == "Point" || PolyType == "Marker") {
          document.body.classList.add("measureCur");
        } else {
          document.body.classList.add("drawCur");
        }
      } else {
        viewer.enableCursorStyle = true;
        tooltip.setVisible(false);

        if (PolyType == "Point" || PolyType == "Marker") {
          document.body.classList.remove('measureCur');
        } else {
          document.body.classList.remove('drawCur');
        }
      }
    });
    var clearMovFn = DrawHandler.movingEvt.addEventListener(function (windowPosition) {
      if (windowPosition.x < 200 && windowPosition.y < 150) {
        tooltip.setVisible(false);
        return;
      }
      //     tooltip.showAt(windowPosition, tiptext);
      // } else if (toolTipObj && toolTipObj.beforeDrawing) {
      //     tooltip.showAt(windowPosition, toolTipObj.beforeDrawing);
      // }else if (DrawHandler.isDrawing && toolTipObj.isDrawing) {
      //     tooltip.showAt(windowPosition, toolTipObj.isDrawing);
      // }

      if (DrawHandler.polyline && DrawHandler.isDrawing) {
        var p = _toConsumableArray(DrawHandler.polyline.positions);

        if (PolyType == "Polygon") {
          //画面时，需要首尾相连
          p.push(p[0]);
        }
        window.polylineTransparent.show = true;
        window.polylineTransparent.positions = p;
      }
    });
    var clearDrawFn = DrawHandler.drawEvt.addEventListener(function (result) {
      if (!result.object.positions && PolyType != "Point" && PolyType != "Box") {
        tooltip.showAt(result, '<p>请绘制正确的多边形</p>');
        DrawHandler.polygon.show = false;
        DrawHandler.polyline.show = false;
        DrawHandler.deactivate();
        DrawHandler.activate();
        return;
      }

      if (PolyType == "Box") {
        resolve({
          result: result
        });
        return;
      }

      if (PolyType == "Point" || PolyType == "Marker") {
        DrawHandler.clear(); // 不显示绘制的点

        resolve({
          result: result
        });
      } else {
        //半透线
        window.polylineTransparent.show = lineVisible;

        if (lineVisible) {
          if (PolyType == "Polygon" && lineVisible) {
            DrawHandler.polygon._polygon._material._color._value.alpha = 0.1; //绘制面透明度

            var p2 = _toConsumableArray(result.object.positions); //画面时，需要首尾相连


            p2.push(p2[0]);
            window.polylineTransparent.positions = p2;
          }
        }

        var positions = CartesiantoDegrees(result.object.positions);
        resolve({
          result: result,
          positions: positions
        });
      }

      clearActFn();
      clearMovFn();
      clearDrawFn();
    });
  });
}; //清除


var clearHandlerDrawing = function clearHandlerDrawing(PolyType) {
  var DrawHandler;

  if (!PolyType) {
    DrawHandler = window.handlerPolygon;
  } else {
    DrawHandler = judgeDrawHandlerType(PolyType);
  }
  if (!DrawHandler) return;
  DrawHandler.deactivate();
  DrawHandler.clear();
  viewer.enableCursorStyle = true; // document.body.classList.remove("drawCur");
  // document.body.classList.remove("measureCur");

  window.tooltip.setVisible(false);

  if (window.polylineTransparent) {
    window.polylineTransparent.show = false;
  }
}; // 类型判断


var judgeDrawHandlerType = function judgeDrawHandlerType(PolyType) {
  var DrawHandler;

  switch (PolyType) {
    case "Point":
      DrawHandler = window.handlerPoint;
      break;

    case "Polyline":
      DrawHandler = window.handlerPolyline;
      break;

    case "Polygon":
      DrawHandler = window.handlerPolygon;
      break;

    case "Marker":
      DrawHandler = window.handlerMarker;
      break;

    case "Box":
      DrawHandler = window.handlerBox;
      break;
  }

  return DrawHandler;
};

var common = {
  initHandler: initHandler,
  handlerDrawing: handlerDrawing,
  clearHandlerDrawing: clearHandlerDrawing
};

function terrainFlood(props) {
  // 设置默认值数据
  var state = reactive({
    maxHeight: 9000,
    //最大可见高程
    minHeight: 1000,
    //最小可见高程
    floodHeight: [1000, 9000],
    currentHeight: 1000,
    //当前高程
    floodTrans: 0.8,
    //透明度
    cheackedBand: 'band1',
    //当前选择颜色
    colorBandShow: false,
    //颜色下拉框显隐
    floodSpeed: 800,
    //速度
    floodPositions: [],
    lineVisible: true //是否显示绘制线

  }); // 传入props改变默认值

  if (props) {
    for (var key in props) {
      if (state.hasOwnProperty(key)) {
        if (props[key] != undefined) state[key] = props[key];
      } else {
        tool.Message.errorMsg(resource.AttributeError + key);
      }
    }
  } // 初始化数据


  var floodDisplayMode = Cesium.HypsometricSettingEnum.DisplayMode.FACE;
  var hypFlood = new Cesium.HypsometricSetting();
  var floodColorTable = new Cesium.ColorTable();
  var colors = tool.gradientColors("#95E9F9", "#002794", 20, 0.8); // 0-4500米颜色取值

  colors.forEach(function (color, index) {
    var h = 500 + 200 * index;
    floodColorTable.insert(h, Cesium.Color.fromCssColorString(color));
  });
  floodColorTable.insert(9000, new Cesium.Color(0, 39 / 255, 148 / 255, 1));
  floodColorTable.insert(0, new Cesium.Color(149 / 255, 232 / 255, 249 / 255, 0.5));
  var interval;
  var floodPosition = [];
  /*
   ***地形淹没分析模块***
  */
  // 分析

  function floodBegin(e) {
    e.preventDefault();
    hypFlood.DisplayMode = floodDisplayMode;
    hypFlood._lineColor = new Cesium.Color(1.0, 0.0, 0.0, 1.0);
    hypFlood.MinVisibleValue = state.minHeight;
    hypFlood.MaxVisibleValue = 0;
    hypFlood.ColorTableMinKey = 1;
    hypFlood.ColorTableMaxKey = 9000;
    hypFlood.ColorTable = floodColorTable;
    hypFlood.Opacity = state.floodTrans;
    hypFlood.LineInterval = 200.0;

    if (!window.handlerPolygon) {
      common.initHandler("Polygon");
    }

    if (props && props.floodPositions) {
      floodUpdate(props.floodPositions);
      return;
    }

    common.handlerDrawing("Polygon", state.lineVisible).then(function (res) {
      var handlerPolygon = window.handlerPolygon;
      floodUpdate(res.positions);
      handlerPolygon.polygon.show = false; // handlerPolygon.polyline.show = false;

      handlerPolygon.deactivate();
    }, function (err) {
      console.log(err);
    });
    window.handlerPolygon.activate();

    if (!viewer.scene.pickPositionSupported) {
      tool.Message.errorMsg(resource.NoPickPositionSupported);
    }
  }

  function floodUpdate(positions) {
    if (positions) {
      floodPosition = positions;
    }

    var currentH = parseFloat(state.minHeight);
    hypFlood.CoverageArea = positions;
    interval = setInterval("flood()", 100);

    window.flood = function () {
      if (currentH <= state.maxHeight) {
        state.currentHeight = parseInt(currentH);
      }

      if (currentH > state.maxHeight) {
        state.currentHeight = state.maxHeight;
        clearInterval(interval);
        return;
      }

      hypFlood.MaxVisibleValue = currentH;

      try {
        viewer.scene.globe.HypsometricSetting = {
          hypsometricSetting: hypFlood,
          analysisMode: Cesium.HypsometricSettingEnum.AnalysisRegionMode.ARM_REGION
        };
      } catch (err) {
        console.log(err);
        clearInterval(interval);
      }
      currentH += parseFloat(state.floodSpeed) / 10;
    };
  }

  function floodClear(e) {
    e.preventDefault();
    floodPosition = [];
    if (!window.handlerPolygon) return;
    viewer.scene.globe.HypsometricSetting = undefined;
    clearInterval(interval);
    common.clearHandlerDrawing("Polygon");
  }

  function changeColor(band) {
    state.colorBandShow = false;
    state.cheackedBand = band;
  }

  watch(function () {
    return state.floodTrans;
  }, function (val) {
    hypFlood.Opacity = parseFloat(val);

    if (floodPosition.length == 0) {
      return;
    }

    viewer.scene.globe.HypsometricSetting = {
      hypsometricSetting: hypFlood,
      analysisMode: Cesium.HypsometricSettingEnum.AnalysisRegionMode.ARM_REGION
    };
  });
  watch(function () {
    return state.floodHeight;
  }, function (val) {
    state.minHeight = val[0];
    state.maxHeight = val[1];
  });
  watch(function () {
    return state.minHeight;
  }, function (val) {
    hypFlood.MinVisibleValue = parseInt(val);

    if (floodPosition.length == 0) {
      state.currentHeight = parseInt(val);
      return;
    }

    viewer.scene.globe.HypsometricSetting = {
      hypsometricSetting: hypFlood,
      analysisMode: Cesium.HypsometricSettingEnum.AnalysisRegionMode.ARM_REGION
    };
  });
  watch(function () {
    return state.maxHeight;
  }, function (val) {
    hypFlood.MaxVisibleValue = parseInt(val);

    if (floodPosition.length == 0) {
      return;
    }

    viewer.scene.globe.HypsometricSetting = {
      hypsometricSetting: hypFlood,
      analysisMode: Cesium.HypsometricSettingEnum.AnalysisRegionMode.ARM_REGION
    };
  });
  watch(function () {
    return state.cheackedBand;
  }, function (val) {
    floodColorTable = colorBandsChange(val);
    hypFlood.ColorTable = floodColorTable;

    if (floodPosition.length == 0) {
      return;
    }

    if (interval) {
      viewer.scene.globe.HypsometricSetting = {
        hypsometricSetting: hypFlood,
        analysisMode: Cesium.HypsometricSettingEnum.AnalysisRegionMode.ARM_REGION
      };
    }
  }); // 销毁

  onBeforeUnmount(function () {
    hypFlood.destroy();
    floodColorTable.destroy();
    hypFlood = undefined;
    floodColorTable = undefined;
  });
  return _objectSpread2(_objectSpread2({}, toRefs(state)), {}, {
    floodBegin: floodBegin,
    floodClear: floodClear,
    changeColor: changeColor,
    floodPosition: floodPosition
  });
}

function colorBandsChange(val) {
  var floodColorTable = new Cesium.ColorTable();

  switch (val) {
    case "band1":
      floodColorTable.insert(9000, new Cesium.Color(0, 39 / 255, 148 / 255));
      floodColorTable.insert(0, new Cesium.Color(149 / 255, 232 / 255, 249 / 255));
      break;

    case "band2":
      floodColorTable.insert(9000, new Cesium.Color(162 / 255, 251 / 255, 194 / 255));
      floodColorTable.insert(0, new Cesium.Color(1, 103 / 255, 103 / 255));
      break;

    case "band3":
      floodColorTable.insert(9000, new Cesium.Color(230 / 255, 198 / 255, 1));
      floodColorTable.insert(0, new Cesium.Color(157 / 255, 0, 1));
      break;

    case "band4":
      floodColorTable.insert(9000, new Cesium.Color(210 / 255, 15 / 255, 15 / 255));
      floodColorTable.insert(6000, new Cesium.Color(221 / 255, 224 / 255, 7 / 255));
      floodColorTable.insert(5000, new Cesium.Color(20 / 255, 187 / 255, 18 / 255));
      floodColorTable.insert(4000, new Cesium.Color(0, 161 / 255, 1));
      floodColorTable.insert(0, new Cesium.Color(9 / 255, 9 / 255, 212 / 255));
      break;

    case "band5":
      floodColorTable.insert(9000, new Cesium.Color(186 / 255, 1, 229 / 255));
      floodColorTable.insert(0, new Cesium.Color(26 / 255, 185 / 255, 156 / 255));
      break;

    default:
      floodColorTable.insert(9000, new Cesium.Color(0, 39 / 255, 148 / 255));
      floodColorTable.insert(0, new Cesium.Color(149 / 255, 232 / 255, 249 / 255));
      break;
  }
  return floodColorTable;
}

var script = {
  name: "Sm3dTerrainFlood",
  props: {
    //最大可见高层
    maxHeight: {
      type: Number,
      "default": 8000
    },
    //最小可见高程
    minHeight: {
      type: Number,
      "default": 1000
    },
    //选择颜色
    cheackedBand: {
      type: String,
      "default": "band1"
    },
    //淹没速度
    floodSpeed: {
      type: Number,
      "default": 800
    },
    //透明度
    floodTrans: {
      type: Number,
      "default": 0.8
    },
    //初始化传入分析区域
    floodPositions: {
      type: Array
    },
    //是否显示绘制后的线
    lineVisible: {
      type: Boolean,
      "default": true
    }
  },
  methods: {
    formatTooltip: function formatTooltip(val) {
      return val + "米";
    },
    formatTooltip2: function formatTooltip2(val) {
      return val + "米/秒";
    }
  },
  setup: function setup(props) {
    var _terrainFlood = terrainFlood(props),
        floodHeight = _terrainFlood.floodHeight,
        currentHeight = _terrainFlood.currentHeight,
        floodSpeed = _terrainFlood.floodSpeed,
        floodBegin = _terrainFlood.floodBegin,
        floodClear = _terrainFlood.floodClear;

    return {
      floodHeight: floodHeight,
      currentHeight: currentHeight,
      floodSpeed: floodSpeed,
      floodBegin: floodBegin,
      floodClear: floodClear
    };
  }
};

var _hoisted_1 = {
  id: "terrain-flood-panel",
  "class": "sm-panel"
};
var _hoisted_2 = {
  "class": "sm-function-module-sub-section",
  style: {
    "margin": "0"
  }
};
var _hoisted_3 = {
  "class": "sm-half-L"
};
var _hoisted_4 = {
  style: {
    "width": "40%"
  }
};
var _hoisted_5 = {
  "class": "sm-half-L"
};
var _hoisted_6 = {
  style: {
    "width": "40%"
  }
};
var _hoisted_7 = {
  "class": "sm-half-L"
};
var _hoisted_8 = {
  style: {
    "width": "40%"
  }
};
var _hoisted_9 = {
  "class": "boxchild"
};
function render(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_el_slider = resolveComponent("el-slider");

  var _directive_stopdrag = resolveDirective("stopdrag");

  var _directive_drag = resolveDirective("drag");

  return withDirectives((openBlock(), createElementBlock("div", _hoisted_1, [withDirectives((openBlock(), createElementBlock("div", _hoisted_2, [createElementVNode("div", _hoisted_3, [createElementVNode("label", _hoisted_4, toDisplayString(_ctx.Resource.visibleHeight), 1
  /* TEXT */
  ), createVNode(_component_el_slider, {
    modelValue: $setup.floodHeight,
    "onUpdate:modelValue": _cache[0] || (_cache[0] = function ($event) {
      return $setup.floodHeight = $event;
    }),
    min: 0,
    max: 9000,
    range: "",
    step: 1,
    "input-size": "mini",
    debounce: 500,
    "tooltip-class": "tooltip-class",
    "format-tooltip": $options.formatTooltip,
    style: {
      "width": "58%"
    }
  }, null, 8
  /* PROPS */
  , ["modelValue", "format-tooltip"])]), createElementVNode("div", _hoisted_5, [createElementVNode("label", _hoisted_6, toDisplayString(_ctx.Resource.currentHeight), 1
  /* TEXT */
  ), withDirectives(createElementVNode("input", {
    "class": "sm-input",
    disabled: "",
    type: "number",
    style: {
      "width": "58%"
    },
    "onUpdate:modelValue": _cache[1] || (_cache[1] = function ($event) {
      return $setup.currentHeight = $event;
    })
  }, null, 512
  /* NEED_PATCH */
  ), [[vModelText, $setup.currentHeight]])]), createElementVNode("div", _hoisted_7, [createElementVNode("label", _hoisted_8, toDisplayString(_ctx.Resource.floodSpeed), 1
  /* TEXT */
  ), createVNode(_component_el_slider, {
    modelValue: $setup.floodSpeed,
    "onUpdate:modelValue": _cache[2] || (_cache[2] = function ($event) {
      return $setup.floodSpeed = $event;
    }),
    max: 1000,
    min: 1,
    "input-size": "mini",
    debounce: 500,
    "tooltip-class": "tooltip-class",
    "format-tooltip": $options.formatTooltip2,
    style: {
      "width": "58%"
    }
  }, null, 8
  /* PROPS */
  , ["modelValue", "format-tooltip"])]), createElementVNode("div", _hoisted_9, [createElementVNode("button", {
    onClick: _cache[3] || (_cache[3] = function () {
      return $setup.floodBegin && $setup.floodBegin.apply($setup, arguments);
    }),
    "class": "tbtn",
    type: "button"
  }, toDisplayString(_ctx.Resource.analyze), 1
  /* TEXT */
  ), createElementVNode("button", {
    onClick: _cache[4] || (_cache[4] = function () {
      return $setup.floodClear && $setup.floodClear.apply($setup, arguments);
    }),
    "class": "tbtn tbtn-margin-left",
    type: "button"
  }, toDisplayString(_ctx.Resource.clear), 1
  /* TEXT */
  )])])), [[_directive_stopdrag]])])), [[_directive_drag]]);
}

script.render = render;
script.__file = "src/components/terrain-analysis/terrain-flood/terrain-flood.vue";

script.install = function (app) {
  app.component(script.name, script);
};

export default script;
