import { reactive, toRefs, watch, onBeforeUnmount, resolveComponent, resolveDirective, withDirectives, openBlock, createElementBlock, createElementVNode, toDisplayString, vModelSelect, createVNode } from 'vue';

function _typeof(obj) {
  "@babel/helpers - typeof";

  if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
    _typeof = function (obj) {
      return typeof obj;
    };
  } else {
    _typeof = function (obj) {
      return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
    };
  }

  return _typeof(obj);
}

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    if (enumerableOnly) symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    });
    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(Object(source), true).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(Object(source)).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

function _toConsumableArray(arr) {
  return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread();
}

function _arrayWithoutHoles(arr) {
  if (Array.isArray(arr)) return _arrayLikeToArray(arr);
}

function _iterableToArray(iter) {
  if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter);
}

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}

function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;

  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

  return arr2;
}

function _nonIterableSpread() {
  throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

//随鼠标移动消息提示工具
function createTooltip(frameDiv) {
  var tooltip = function tooltip(frameDiv) {
    var div = document.createElement("DIV");
    div.className = "twipsy right";
    var arrow = document.createElement("DIV");
    arrow.className = "twipsy-arrow";
    div.appendChild(arrow);
    var title = document.createElement("DIV");
    title.className = "twipsy-inner";
    div.appendChild(title);
    this._div = div;
    this._title = title;
    this.message = "";
    frameDiv.appendChild(div);
    var that = this;

    div.onmousemove = function (evt) {
      that.showAt({
        x: evt.clientX,
        y: evt.clientY
      }, that.message);
    };
  };

  tooltip.prototype.setVisible = function (visible) {
    this._div.style.display = visible ? "block" : "none";
  };

  tooltip.prototype.showAt = function (position, message) {
    if (position && message) {
      this.setVisible(true);
      this._title.innerHTML = message;
      this._div.style.left = position.x + 10 + "px";
      this._div.style.top = position.y - this._div.clientHeight / 2 + "px";
      this.message = message;
    }
  };

  return new tooltip(frameDiv);
}

/*
* 常用工具类
*/
//axios本版本不支持jsonp
var axiosJsonp = function axiosJsonp(url) {
  if (!url) {
    console.error('Axios.JSONP 至少需要一个url参数!');
    return;
  }

  return new Promise(function (resolve, reject) {
    window.jsonCallBack = function (result) {
      resolve(result);
    };

    var JSONP = document.createElement("script");
    JSONP.type = "text/javascript";
    JSONP.src = "".concat(url, "&callback=jsonCallBack");
    document.getElementsByTagName("head")[0].appendChild(JSONP);
    setTimeout(function () {
      document.getElementsByTagName("head")[0].removeChild(JSONP);
    }, 500);
  });
}; //判断两数组或对象相等


var isEqualArr = function isEqualArr(arg1, arg2) {
  if (!arg1 || !arg2) return true;
  var bol = true;

  if (Object.keys(arg1).length != Object.keys(arg2).length) {
    return false;
  }

  for (var key in arg1) {
    if (_typeof(arg1[key]) == 'object') {
      bol = isSame(arg1[key], arg2[key]);

      if (!bol) {
        break;
      }
    } else if (arg1[key] != arg2[key]) {
      bol = false;
      break;
    }
  }

  return bol;
}; //坐标转化
//笛卡尔转经纬度


var CartesiantoDegrees = function CartesiantoDegrees(Cartesians) {
  var array = [].concat(Cartesians);
  var positions = [];

  for (var i = 0, len = array.length; i < len; i++) {
    var cartographic = Cesium.Cartographic.fromCartesian(array[i]);
    var longitude = Cesium.Math.toDegrees(cartographic.longitude);
    var latitude = Cesium.Math.toDegrees(cartographic.latitude);
    var h = cartographic.height;

    if (positions.indexOf(longitude) == -1 && positions.indexOf(latitude) == -1) {
      positions.push(longitude);
      positions.push(latitude);
      positions.push(h);
    }
  }

  return positions;
}; //笛卡尔转经纬度(每个点是独立的对象)


var CartesiantoDegreesObjs = function CartesiantoDegreesObjs(Cartesians) {
  var array = [].concat(Cartesians);
  var positions = [];

  for (var i = 0, len = array.length; i < len; i++) {
    var cartographic = Cesium.Cartographic.fromCartesian(array[i]);
    var obj = {
      longitude: Cesium.Math.toDegrees(cartographic.longitude),
      latitude: Cesium.Math.toDegrees(cartographic.latitude),
      height: cartographic.height
    };
    positions.push(obj);
  }

  return positions;
}; // 弧度转经纬度


var CartographictoDegrees = function CartographictoDegrees(wgsPosition) {
  var longitude = Cesium.Math.toDegrees(wgsPosition.longitude);
  var latitude = Cesium.Math.toDegrees(wgsPosition.latitude);
  var height = wgsPosition.height;
  return [longitude, latitude, height];
}; //去重函数  数组


var unique = function unique(arr) {
  var res = [];
  var json = {};

  for (var i = 0; i < arr.length; i++) {
    if (!json[arr[i]]) {
      res.push(arr[i]);
      json[arr[i]] = 1;
    }
  }

  return res;
}; // 获取渐变色函数


function gradientColors(start, end, steps, gamma) {
  var i,
      j,
      ms,
      me,
      output = [],
      so = [];
  gamma = gamma || 1;

  var normalize = function normalize(channel) {
    return Math.pow(channel / 255, gamma);
  };

  start = parseColor(start).map(normalize);
  end = parseColor(end).map(normalize);

  for (i = 0; i < steps; i++) {
    ms = i / (steps - 1);
    me = 1 - ms;

    for (j = 0; j < 3; j++) {
      so[j] = pad(Math.round(Math.pow(start[j] * me + end[j] * ms, 1 / gamma) * 255).toString(16));
    }

    output.push('#' + so.join(''));
  }

  return output;

  function parseColor(hexStr) {
    return hexStr.length === 4 ? hexStr.substr(1).split('').map(function (s) {
      return 0x11 * parseInt(s, 16);
    }) : [hexStr.substr(1, 2), hexStr.substr(3, 2), hexStr.substr(5, 2)].map(function (s) {
      return parseInt(s, 16);
    });
  }

  function pad(s) {
    return s.length === 1 ? '0' + s : s;
  }
}

function getAngleAndRadian(pointA, pointB) {
  //建立以点A为原点，X轴为east,Y轴为north,Z轴朝上的坐标系
  var transform = Cesium.Transforms.eastNorthUpToFixedFrame(pointA); //向量AB

  var positionvector = Cesium.Cartesian3.subtract(pointB, pointA, new Cesium.Cartesian3()); //因transform是将A为原点的eastNorthUp坐标系中的点转换到世界坐标系的矩阵
  //AB为世界坐标中的向量
  //因此将AB向量转换为A原点坐标系中的向量，需乘以transform的逆矩阵。

  var vector = Cesium.Matrix4.multiplyByPointAsVector(Cesium.Matrix4.inverse(transform, new Cesium.Matrix4()), positionvector, new Cesium.Cartesian3()); //归一化

  var direction = Cesium.Cartesian3.normalize(vector, new Cesium.Cartesian3()); //heading

  var heading1 = Math.atan2(direction.y, direction.x) - Cesium.Math.PI_OVER_TWO;
  var radian = Cesium.Math.TWO_PI - Cesium.Math.zeroToTwoPi(heading1);
  var angle = radian * (180 / Math.PI);

  if (angle < 0) {
    angle = angle + 360;
  }

  return {
    angle: angle,
    radian: radian
  };
}

function getPitch(pointA, pointB) {
  var transfrom = Cesium.Transforms.eastNorthUpToFixedFrame(pointA);
  var vector = Cesium.Cartesian3.subtract(pointB, pointA, new Cesium.Cartesian3());
  var direction = Cesium.Matrix4.multiplyByPointAsVector(Cesium.Matrix4.inverse(transfrom, transfrom), vector, vector);
  Cesium.Cartesian3.normalize(direction, direction); //因为direction已归一化，斜边长度等于1，所以余弦函数等于direction.z

  var radian = Cesium.Math.PI_OVER_TWO - Cesium.Math.acosClamped(direction.z);
  var angle = radian * (180 / Math.PI);

  if (angle < 0) {
    angle = angle + 360;
  }

  return {
    angle: angle,
    radian: radian
  };
}

var tool = {
  axiosJsonp: axiosJsonp,
  isEqualArr: isEqualArr,
  CartesiantoDegrees: CartesiantoDegrees,
  CartesiantoDegreesObjs: CartesiantoDegreesObjs,
  unique: unique,
  gradientColors: gradientColors,
  getAngleAndRadian: getAngleAndRadian,
  CartographictoDegrees: CartographictoDegrees,
  getPitch: getPitch
};

var ResourceCN = {
  showRenderLoopErrors: '渲染时发生错误，已停止渲染。',
  AttributeError: '该组件props没有这个属性：',
  NoPickPositionSupported: "不支持深度纹理,无法绘制多边形，地形操作功能无法使用！",
  NoTerrain: "请在地形里使用地形组件！",
  initViewerWarn: '请先初始化viewer!',
  MoveMouseHeightBox: '点击鼠标左键结束矩形绘制，移动鼠标绘制box高度',
  RightClickEndDrawing: '右键单击结束绘制',
  LeftClickBottomBox: '点击鼠标左键，开始绘制矩形作为box底面',
  ClickModelAddBox: '点击模型，添加裁剪盒子',
  SkyLineWarn: "获取天际线体前，请先绘制天际线！",
  SkyLineBody: '天际线体',
  ShadowqueryWarn: "此操作需要先开启阴影！",
  VeiwshedBody: '可视体',
  VeiwshedBodyHidden: '不可视体',
  EchartsErr: "二维显示需要echarts支持，未找到相关依赖！",
  BaseMapImg: '底图',
  tip1: '<p>点击左键确定操作区域中间点</p><p>右键单击结束绘制</p>'
};

// 组件内部的语言资源：主要包括提示信息
var currentLanguage, Resource$1;
var cookieLanguage = getLang().toLowerCase();

function getLang() {
  //浏览器语言  IE用browserLanguage，非IE使用language进行判断
  var lang = (navigator.language || navigator.browserLanguage).toLowerCase();
  window.lang = lang; //判断portal设置语言 通过cookie获取
  //   const cookies = document.cookie.split(';');
  //   if (cookies.length > 0) {
  //     cookies.forEach(function (cookie) {
  //       const arr = cookie.split('=');
  //       if (arr[0].toLowerCase().trim() === 'language') {
  //         lang = arr[1];
  //         return;
  //       }
  //     });
  //   }

  return lang;
}

if (cookieLanguage !== undefined) {
  currentLanguage = cookieLanguage;
} else {
  currentLanguage = (navigator.language || navigator.browserLanguage).toLowerCase(); // 获取当前浏览器的语言
}

if (currentLanguage.startsWith('zh')) {
  Resource$1 = ResourceCN;
} else if (currentLanguage.startsWith('ja')) {
  Resource$1 = ResourceCN;
} else {
  Resource$1 = ResourceCN;
}

var resource = Resource$1;

/**
 * 初始化
 * DrawMode：类型
 * clampMode：模式
 */

var initHandler = function initHandler(DrawMode, clampMode) {
  var clampmode = 0;

  if (clampMode) {
    clampmode = clampMode;
  }

  switch (DrawMode) {
    case "Point":
      window.handlerPoint = new Cesium.DrawHandler(viewer, Cesium.DrawMode.Point);
      break;

    case "Polyline":
      window.handlerPolyline = new Cesium.DrawHandler(viewer, Cesium.DrawMode.Line, clampmode);
      break;

    case "Polygon":
      window.handlerPolygon = new Cesium.DrawHandler(viewer, Cesium.DrawMode.Polygon, clampmode);
      break;

    case "Marker":
      window.handlerMarker = new Cesium.DrawHandler(viewer, Cesium.DrawMode.Marker, clampmode);
      break;

    case "Box":
      window.handlerBox = new Cesium.DrawHandler(viewer, Cesium.DrawMode.Box, clampmode);
      break;
  }

  if (!window.tooltip) {
    window.tooltip = createTooltip(viewer._element);
  } // 半透线创建


  if (!window.polylineCollection) {
    window.polylineCollection = new Cesium.PolylineCollection({
      translucentRS: Cesium.RenderState.fromCache({
        depthMask: false,
        depthTest: {
          enabled: false
        }
      })
    });
    window.polylineTransparent = window.polylineCollection.add({
      width: 2,
      material: Cesium.Material.fromType(Cesium.Material.ColorType, {
        color: Cesium.Color.fromCssColorString("#51ff00").withAlpha(0.3)
      })
    });
    viewer.scene.primitives.add(window.polylineCollection);
  }
};
/**
 * 绘制
 * PolyType：类型 
 * lineVisib：绘制时是否显示绘制线（boolean）
 * toolTipObj：绘制时提示内容{beforeDrawing：绘制开始前提示(string)，isDrawing：正在绘制时提示,即绘制过程中（string）}
 */


var handlerDrawing = function handlerDrawing(PolyType, lineVisib, toolTipObj) {
  var lineVisible = true;

  if (lineVisib === false) {
    lineVisible = lineVisib;
  }

  var DrawHandler = judgeDrawHandlerType(PolyType); //获取操作对象

  return new Promise(function (resolve, reject) {
    //做一些异步操作
    var tooltip = window.tooltip;
    var clearActFn = DrawHandler.activeEvt.addEventListener(function (isActive) {
      if (isActive == true) {
        viewer.enableCursorStyle = false;
        viewer._element.style.cursor = '';

        if (PolyType == "Point" || PolyType == "Marker") {
          document.body.classList.add("measureCur");
        } else {
          document.body.classList.add("drawCur");
        }
      } else {
        viewer.enableCursorStyle = true;
        tooltip.setVisible(false);

        if (PolyType == "Point" || PolyType == "Marker") {
          document.body.classList.remove('measureCur');
        } else {
          document.body.classList.remove('drawCur');
        }
      }
    });
    var clearMovFn = DrawHandler.movingEvt.addEventListener(function (windowPosition) {
      if (windowPosition.x < 200 && windowPosition.y < 150) {
        tooltip.setVisible(false);
        return;
      }
      //     tooltip.showAt(windowPosition, tiptext);
      // } else if (toolTipObj && toolTipObj.beforeDrawing) {
      //     tooltip.showAt(windowPosition, toolTipObj.beforeDrawing);
      // }else if (DrawHandler.isDrawing && toolTipObj.isDrawing) {
      //     tooltip.showAt(windowPosition, toolTipObj.isDrawing);
      // }

      if (DrawHandler.polyline && DrawHandler.isDrawing) {
        var p = _toConsumableArray(DrawHandler.polyline.positions);

        if (PolyType == "Polygon") {
          //画面时，需要首尾相连
          p.push(p[0]);
        }
        window.polylineTransparent.show = true;
        window.polylineTransparent.positions = p;
      }
    });
    var clearDrawFn = DrawHandler.drawEvt.addEventListener(function (result) {
      if (!result.object.positions && PolyType != "Point" && PolyType != "Box") {
        tooltip.showAt(result, '<p>请绘制正确的多边形</p>');
        DrawHandler.polygon.show = false;
        DrawHandler.polyline.show = false;
        DrawHandler.deactivate();
        DrawHandler.activate();
        return;
      }

      if (PolyType == "Box") {
        resolve({
          result: result
        });
        return;
      }

      if (PolyType == "Point" || PolyType == "Marker") {
        DrawHandler.clear(); // 不显示绘制的点

        resolve({
          result: result
        });
      } else {
        //半透线
        window.polylineTransparent.show = lineVisible;

        if (lineVisible) {
          if (PolyType == "Polygon" && lineVisible) {
            DrawHandler.polygon._polygon._material._color._value.alpha = 0.1; //绘制面透明度

            var p2 = _toConsumableArray(result.object.positions); //画面时，需要首尾相连


            p2.push(p2[0]);
            window.polylineTransparent.positions = p2;
          }
        }

        var positions = CartesiantoDegrees(result.object.positions);
        resolve({
          result: result,
          positions: positions
        });
      }

      clearActFn();
      clearMovFn();
      clearDrawFn();
    });
  });
}; //清除


var clearHandlerDrawing = function clearHandlerDrawing(PolyType) {
  var DrawHandler;

  if (!PolyType) {
    DrawHandler = window.handlerPolygon;
  } else {
    DrawHandler = judgeDrawHandlerType(PolyType);
  }
  if (!DrawHandler) return;
  DrawHandler.deactivate();
  DrawHandler.clear();
  viewer.enableCursorStyle = true; // document.body.classList.remove("drawCur");
  // document.body.classList.remove("measureCur");

  window.tooltip.setVisible(false);

  if (window.polylineTransparent) {
    window.polylineTransparent.show = false;
  }
}; // 类型判断


var judgeDrawHandlerType = function judgeDrawHandlerType(PolyType) {
  var DrawHandler;

  switch (PolyType) {
    case "Point":
      DrawHandler = window.handlerPoint;
      break;

    case "Polyline":
      DrawHandler = window.handlerPolyline;
      break;

    case "Polygon":
      DrawHandler = window.handlerPolygon;
      break;

    case "Marker":
      DrawHandler = window.handlerMarker;
      break;

    case "Box":
      DrawHandler = window.handlerBox;
      break;
  }

  return DrawHandler;
};

/**
 * 编辑功能
 * EditPositions：编辑前的区域，用于编辑后的比较变化（array）
 * isEditZ：是否编辑z轴
 * callback：编辑后触发的回调函数
 * 注意：为了更好的性能，编辑功能是全局的唯一的，所以只能进行当前操作的编辑
 */

var Edit = function Edit(EditPositions, isEditZ, callback) {
  if (!window.selectHandler) {
    window.selectHandler = new Cesium.ScreenSpaceEventHandler(viewer.scene.canvas);
  }

  var selectHandler = window.selectHandler;

  if (window.handlerPolygon && window.handlerPolygon.polygon) {
    window.handlerPolygon.polygon.show = true;
  }

  selectHandler.setInputAction(function () {
    var entity = viewer.selectedEntity;
    var editHandler = window.editHandler;

    if (!entity) {
      if (editHandler) {
        editHandler && editHandler.deactivate();
      }

      return;
    }

    if (!editHandler) {
      window.editHandler = new Cesium.EditHandler(viewer, entity);

      if (isEditZ) {
        window.editHandler.isEditZ = isEditZ;
      } else {
        window.editHandler.isEditZ = false;
      }

      window.editHandler.activate();
    } else {
      editHandler.deactivate();
      editHandler.setEditObject(entity);
      editHandler.activate();
    }

    selectHandler.setInputAction(function () {
      entity = viewer.selectedEntity;
      editHandler = window.editHandler;

      if (!entity) {
        return;
      }

      if (editHandler && editHandler._positions) {
        var positions = CartesiantoDegrees(editHandler._positions);

        if (isEqualArr(EditPositions, positions)) {
          return;
        } else {
          EditPositions = positions;

          if (callback) {
            callback(positions, window.editHandler);
          }
        }

        if (window.handlerPolygon && window.handlerPolygon.polygon && window.handlerPolygon.polygon.show) {
          var p3 = _toConsumableArray(editHandler._positions);

          p3.push(p3[0]);
          window.polylineTransparent.positions = p3; //半透线
        }
      }
    }, Cesium.ScreenSpaceEventType.LEFT_UP);
  }, Cesium.ScreenSpaceEventType.LEFT_CLICK);
};

var clearEditHandler = function clearEditHandler() {
  if (window.editHandler) {
    window.editHandler.deactivate();
    window.editHandler.clear();
  }

  if (window.selectHandler) {
    //移除鼠标移动事件监听
    window.selectHandler.removeInputAction(Cesium.ScreenSpaceEventType.LEFT_UP);
    window.selectHandler.removeInputAction(Cesium.ScreenSpaceEventType.LEFT_CLICK);
    window.selectHandler.destroy();
    window.selectHandler = null;
  }
};

function createTooltip$1(frameDiv) {
  var tooltip = function tooltip(frameDiv) {
    var div = document.createElement('DIV');
    div.className = "tooltip";
    this._div = div;
    this.message = '';
    frameDiv.appendChild(div);
  };

  tooltip.prototype.setVisible = function (visible) {
    if (visible) {
      this._div.style.right = '10px';
    } else {
      this._div.style.right = '-300px';
    }
  };

  tooltip.prototype.showAt = function (message, top) {
    //top:200px => string
    if (top) {
      this._div.style.top = top;
    }

    if (message) {
      this.setVisible(true);
      this._div.innerHTML = message;
    }
  };

  return new tooltip(frameDiv);
}

// 创建一个简单的store状态管理

var storeState = reactive({
  isViewer: false,
  //viewer初始化标志
  changeLayers: 0,
  //图层改变加载完毕监听
  changeGeometrys: 0 //三维分析体改变标志

});

function terrainSlope(props) {
  // 设置默认值数据
  var slopData = reactive({
    analysisArea: 'ARM_REGION',
    //分析区域
    displayMode: 'FACE_AND_ARROW',
    //显示模式
    wideMaxR: 90,
    //最大坡度
    wideMinR: 0,
    //最小坡度
    slopeInterval: [0, 90],
    trans: 0.8,
    //透明度
    isEdit: false,
    //是否编辑
    slopePositions: [],
    lineVisible: true //是否显示绘制线

  }); // 传入props改变默认值

  if (props) {
    for (var key in props) {
      if (slopData.hasOwnProperty(key)) {
        if (props[key] != undefined) slopData[key] = props[key];
      } else {
        tool.Message.errorMsg(resource.AttributeError + key);
      }
    }
  } // 初始化数据


  var tipFlag = true;
  var slope = new Cesium.SlopeSetting(); //分析对象

  var wide = Cesium.HypsometricSettingEnum.AnalysisRegionMode[slopData.analysisArea]; //默认分析区域值

  var disMode = Cesium.SlopeSettingEnum.DisplayMode[slopData.displayMode]; //显示模式

  var SlopColorTable = new Cesium.ColorTable(); //颜色

  var slopePosition = []; //保存当前分析区域

  SlopColorTable.insert(80, new Cesium.Color(255 / 255, 0 / 255, 0 / 255));
  SlopColorTable.insert(50, new Cesium.Color(221 / 255, 224 / 255, 7 / 255));
  SlopColorTable.insert(30, new Cesium.Color(20 / 255, 187 / 255, 18 / 255));
  SlopColorTable.insert(20, new Cesium.Color(0, 161 / 255, 1));
  SlopColorTable.insert(0, new Cesium.Color(9 / 255, 9 / 255, 255 / 255));
  /*
   ***坡度分析模块***
  */
  //初始化分析区域 （后面有需要可以添加监听）

  if (props && props.slopePositions) {
    slopeUpdate(props.slopePositions);
  }

  if (storeState.isViewer) {
    if (!window.tooltip) {
      window.tooltip = createTooltip$1(viewer._element);
    }
  } //viewer 初始化完成的监听


  watch(function () {
    return storeState.isViewer;
  }, function (val) {
    if (val) {
      if (!window.tooltip) {
        window.tooltip = createTooltip$1(viewer._element);
      }
    }
  }); // 分析

  function startSlope(e) {
    e.preventDefault();
    tooltip.setVisible(false);

    if (tipFlag) {
      //只提示一次
      window.tooltip.showAt(' <p>点击鼠标左键绘制分析区域</p><p>点击鼠标右键结束绘制</p><p>坡度坡向分析需要带法线地形</p>', '250px');
      tipFlag = false;
    }

    slope.DisplayMode = disMode;
    slope.MaxVisibleValue = slopData.wideMaxR;
    slope.MinVisibleValue = slopData.wideMinR;
    slope.ColorTable = SlopColorTable;
    slope.Opacity = slopData.trans; // this.positions = [];
    // viewer.scene.globe.enableLighting = true;

    if (!window.handlerPolygon) {
      initHandler("Polygon");
    }

    handlerDrawing("Polygon", slopData.lineVisible).then(function (res) {
      slopePosition = res.positions;
      slopeUpdate(slopePosition);
      var handlerPolygon = window.handlerPolygon;
      handlerPolygon.polygon.show = false;
      handlerPolygon.polyline.show = false;
      handlerPolygon.deactivate();

      if (slopData.isEdit) {
        Edit(slopePosition, false, slopeUpdate);
      }
    }, function (err) {
      console.log(err);
    });
    handlerPolygon.activate();

    if (!scene.pickPositionSupported) {
      tool.Message.errorMsg(resource.NoPickPositionSupported);
    }
  }

  function slopeUpdate(p) {
    if (p) {
      slopePosition = p;
    }

    slope.CoverageArea = p;
    viewer.scene.globe.SlopeSetting = {
      slopeSetting: slope,
      analysisMode: wide
    };
  }

  function clearSlope(e) {
    e.preventDefault();
    slopePosition = [];
    if (!window.handlerPolygon) return;
    viewer.scene.globe.SlopeSetting = {
      analysisMode: Cesium.HypsometricSettingEnum.AnalysisRegionMode.ARM_NONE
    };
    tooltip.setVisible(false);
    clearHandlerDrawing("Polygon");
    clearEditHandler();
  }
  watch(function () {
    return slopData.analysisArea;
  }, function (val) {
    switch (val) {
      case "ARM_REGION":
        {
          wide = Cesium.HypsometricSettingEnum.AnalysisRegionMode.ARM_REGION;
        }
        break;

      case "ARM_ALL":
        {
          wide = Cesium.HypsometricSettingEnum.AnalysisRegionMode.ARM_ALL;
        }
        break;

      case "ARM_NONE":
        {
          wide = Cesium.HypsometricSettingEnum.AnalysisRegionMode.ARM_NONE;
        }
        break;
    }

    if (slopePosition.length == 0) {
      return;
    }

    slopeUpdate(slopePosition);
  });
  watch(function () {
    return slopData.wideMaxR;
  }, function (val) {
    slope.MaxVisibleValue = parseFloat(val);

    if (slopePosition.length == 0) {
      return;
    }

    viewer.scene.globe.SlopeSetting = {
      slopeSetting: slope,
      analysisMode: wide
    };
  });
  watch(function () {
    return slopData.wideMinR;
  }, function (val) {
    slope.MinVisibleValue = parseFloat(val);

    if (slopePosition.length == 0) {
      return;
    }

    viewer.scene.globe.SlopeSetting = {
      slopeSetting: slope,
      analysisMode: wide
    };
  });
  watch(function () {
    return slopData.slopeInterval;
  }, function (val) {
    slopData.wideMinR = val[0];
    slopData.wideMaxR = val[1]; // slope.MinVisibleValue = parseFloat(val[0]);
    // slope.MaxVisibleValue = parseFloat(val[1]);
    // if (slopePosition.length == 0) {
    //     return;
    // }
    // viewer.scene.globe.SlopeSetting = {
    //     slopeSetting: slope,
    //     analysisMode: wide,
    // };
  });
  watch(function () {
    return slopData.displayMode;
  }, function (val) {
    switch (val) {
      case "FACE":
        {
          disMode = Cesium.SlopeSettingEnum.DisplayMode.FACE;
        }
        break;

      case "ARROW":
        {
          disMode = Cesium.SlopeSettingEnum.DisplayMode.ARROW;
        }
        break;

      case "FACE_AND_ARROW":
        {
          disMode = Cesium.SlopeSettingEnum.DisplayMode.FACE_AND_ARROW;
        }
        break;
    }

    slope.DisplayMode = disMode;

    if (slopePosition.length == 0) {
      return;
    }

    slopeUpdate(slopePosition);
  });
  watch(function () {
    return slopData.trans;
  }, function (val) {
    slope.Opacity = parseFloat(val);

    if (slopePosition.length == 0) {
      return;
    }

    viewer.scene.globe.SlopeSetting = {
      slopeSetting: slope,
      analysisMode: wide
    };
  });
  watch(function () {
    return slopData.isEdit;
  }, function (val) {
    if (val && window.handlerPolygon) {
      Edit(slopePosition, false, slopeUpdate);
    } else {
      clearEditHandler();

      if (window.handlerPolygon && window.handlerPolygon.polygon) {
        window.handlerPolygon.polygon.show = false;
      }
    }
  }); // 销毁

  onBeforeUnmount(function () {
    slope.destroy();
    SlopColorTable.destroy();
    slope = undefined;
    SlopColorTable = undefined;
  });
  return _objectSpread2(_objectSpread2({}, toRefs(slopData)), {}, {
    startSlope: startSlope,
    clearSlope: clearSlope,
    slopePosition: slopePosition
  });
}

var script = {
  name: "Sm3dTerrainSlope",
  props: {
    //分析区域
    analysisArea: {
      type: String,
      "default": "ARM_REGION"
    },
    //显示模式
    displayMode: {
      type: String,
      "default": "FACE_AND_ARROW"
    },
    //最大坡度
    wideMaxR: {
      type: Number,
      "default": 90
    },
    //最小坡度
    wideMinR: {
      type: Number,
      "default": 0
    },
    //透明度
    trans: {
      type: Number,
      "default": 0.8
    },
    //是否编辑
    isEdit: {
      type: Boolean,
      "default": false
    },
    //初始化传入分析区域
    slopePositions: {
      type: Array
    },
    //是否显示绘制后的线
    lineVisible: {
      type: Boolean,
      "default": true
    }
  },
  methods: {
    formatTooltip: function formatTooltip(val) {
      return Resource.slope + val + "°";
    }
  },
  setup: function setup(props) {
    var _terrainSlope = terrainSlope(props),
        analysisArea = _terrainSlope.analysisArea,
        displayMode = _terrainSlope.displayMode,
        wideMaxR = _terrainSlope.wideMaxR,
        wideMinR = _terrainSlope.wideMinR,
        trans = _terrainSlope.trans,
        isEdit = _terrainSlope.isEdit,
        slopeInterval = _terrainSlope.slopeInterval,
        startSlope = _terrainSlope.startSlope,
        clearSlope = _terrainSlope.clearSlope;

    return {
      analysisArea: analysisArea,
      displayMode: displayMode,
      wideMaxR: wideMaxR,
      wideMinR: wideMinR,
      trans: trans,
      isEdit: isEdit,
      slopeInterval: slopeInterval,
      startSlope: startSlope,
      clearSlope: clearSlope
    };
  }
};

var _hoisted_1 = {
  id: "terrain-slope-panel",
  "class": "sm-panel"
};
var _hoisted_2 = {
  "class": "sm-function-module-sub-section",
  style: {
    "margin": "0"
  }
};
var _hoisted_3 = {
  "class": "sm-half-L"
};
var _hoisted_4 = {
  "class": "label-S"
};
var _hoisted_5 = {
  value: "ARM_REGION"
};
var _hoisted_6 = {
  value: "ARM_ALL"
};
var _hoisted_7 = {
  value: "ARM_NONE"
};
var _hoisted_8 = {
  "class": "sm-half-L"
};
var _hoisted_9 = {
  style: {
    "width": "40%"
  }
};
var _hoisted_10 = {
  "class": "boxchild"
};
function render(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_el_slider = resolveComponent("el-slider");

  var _directive_stopdrag = resolveDirective("stopdrag");

  var _directive_drag = resolveDirective("drag");

  return withDirectives((openBlock(), createElementBlock("div", _hoisted_1, [withDirectives((openBlock(), createElementBlock("div", _hoisted_2, [createElementVNode("div", _hoisted_3, [createElementVNode("label", _hoisted_4, toDisplayString(_ctx.Resource.analysisArea), 1
  /* TEXT */
  ), withDirectives(createElementVNode("select", {
    "class": "sm-select-m",
    style: {
      "width": "60%"
    },
    "onUpdate:modelValue": _cache[0] || (_cache[0] = function ($event) {
      return $setup.analysisArea = $event;
    })
  }, [createElementVNode("option", _hoisted_5, toDisplayString(_ctx.Resource.specifyPolygon), 1
  /* TEXT */
  ), createElementVNode("option", _hoisted_6, toDisplayString(_ctx.Resource.allRegionsAnalysis), 1
  /* TEXT */
  ), createElementVNode("option", _hoisted_7, toDisplayString(_ctx.Resource.allRegionsNOAnalysis), 1
  /* TEXT */
  )], 512
  /* NEED_PATCH */
  ), [[vModelSelect, $setup.analysisArea]])]), createElementVNode("div", _hoisted_8, [createElementVNode("label", _hoisted_9, toDisplayString(_ctx.Resource.slopeRange), 1
  /* TEXT */
  ), createVNode(_component_el_slider, {
    modelValue: $setup.slopeInterval,
    "onUpdate:modelValue": _cache[1] || (_cache[1] = function ($event) {
      return $setup.slopeInterval = $event;
    }),
    min: 0,
    max: 90,
    range: "",
    step: 1,
    "input-size": "mini",
    debounce: 500,
    "tooltip-class": "tooltip-class",
    "format-tooltip": $options.formatTooltip,
    style: {
      "width": "58%"
    }
  }, null, 8
  /* PROPS */
  , ["modelValue", "format-tooltip"])]), createElementVNode("div", _hoisted_10, [createElementVNode("button", {
    onClick: _cache[2] || (_cache[2] = function () {
      return $setup.startSlope && $setup.startSlope.apply($setup, arguments);
    }),
    "class": "tbtn",
    type: "button"
  }, toDisplayString(_ctx.Resource.analyze), 1
  /* TEXT */
  ), createElementVNode("button", {
    onClick: _cache[3] || (_cache[3] = function () {
      return $setup.clearSlope && $setup.clearSlope.apply($setup, arguments);
    }),
    "class": "tbtn tbtn-margin-left",
    type: "button"
  }, toDisplayString(_ctx.Resource.clear), 1
  /* TEXT */
  )])])), [[_directive_stopdrag]])])), [[_directive_drag]]);
}

script.render = render;
script.__file = "src/components/terrain-analysis/terrain-slope/terrain-slope.vue";

script.install = function (app) {
  app.component(script.name, script);
};

export default script;
