import { reactive, onBeforeUnmount, onMounted, openBlock, createElementBlock, renderSlot } from 'vue';

// 创建一个简单的store状态管理

var storeState = reactive({
  isViewer: false,
  //viewer初始化标志
  changeLayers: 0,
  //图层改变加载完毕监听
  changeGeometrys: 0 //三维分析体改变标志

});
var actions = {
  setIsViewer: function setIsViewer(newValue) {
    storeState.isViewer = newValue;
  },
  setChangeLayers: function setChangeLayers(newValue) {
    storeState.changeLayers += 1;
  },
  setGeometrys: function setGeometrys(newValue) {
    storeState.changeGeometrys += 1;
  }
}; // 全局公共数据

var storeDate = {
  geometrys: {},
  //存储当前存在的三位空间查询体：如天际线体，可视域体
  layers: null
};

// 添加s3m

function addS3mLayers(scps, callback) {
  //scps:[{ url, options:{name}]}  无返回值
  var promiseArray = [];

  try {
    if (scps) {
      //加载scps
      scps.forEach(function (scp) {
        promiseArray.push(viewer.scene.addS3MTilesLayerByScp(scp.url, scp.options));
      });
    }

    promiseWhen(promiseArray, callback, 'S3M');
  } catch (e) {
    var widget = viewer.cesiumWidget;

    if (widget._showRenderLoopErrors) {
      var title = "渲染时发生错误，已停止渲染。";
      widget.showErrorPanel(title, undefined, e);
    }
  }
}

function addScene(url, options, callback) {
  //无返回值options:{SceneToken,autoSetView}
  if (options && options.SceneToken) {
    Cesium.Credential.CREDENTIAL = new Cesium.Credential(options.SceneToken);
  }

  var flag = true;

  if (options && options.autoSetView) {
    flag = options.autoSetView;
  }

  if (checkURL(url)) {
    try {
      var s = [viewer.scene.open(url, undefined, {
        'autoSetView': flag
      })];
      promiseWhen(s, callback, 'SCENE');
    } catch (e) {
      var widget = viewer.cesiumWidget;

      if (widget._showRenderLoopErrors) {
        var title = "渲染时发生错误，已停止渲染。";
        widget.showErrorPanel(title, undefined, e);
      }
    }
  }
}

function promiseWhen(promiseArray, callback, type) {
  Cesium.when.all(promiseArray, function (layers) {
    storeDate.layers = viewer.scene.layers.layerQueue;
    actions.setChangeLayers();
    callback(layers[0], type);
    storeDate.layers.forEach(function (s3mlayer) {
      if (!s3mlayer.visibleDistanceMax || s3mlayer.visibleDistanceMax > 12000) {
        s3mlayer.visibleDistanceMax = 12000; //设置模型最可见距离
      }
    });
  }, function (e) {
    var widget = viewer.cesiumWidget;

    if (widget._showRenderLoopErrors) {
      var title = '请检查url地址是否正确？';
      widget.showErrorPanel(title, undefined, e);
    }
  });
}

function checkURL(url) {
  if (url === null || url === "") {
    return false;
  }

  if (url.charAt(0) == '"' || url.charAt(0) == "'") {
    var reg = /^['|"](.*)['|"]$/;
    url = url.replace(reg, "$1");
  }

  return true;
}

function _classCallCheck(instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
}

function _defineProperties(target, props) {
  for (var i = 0; i < props.length; i++) {
    var descriptor = props[i];
    descriptor.enumerable = descriptor.enumerable || false;
    descriptor.configurable = true;
    if ("value" in descriptor) descriptor.writable = true;
    Object.defineProperty(target, descriptor.key, descriptor);
  }
}

function _createClass(Constructor, protoProps, staticProps) {
  if (protoProps) _defineProperties(Constructor.prototype, protoProps);
  if (staticProps) _defineProperties(Constructor, staticProps);
  return Constructor;
}

function _inherits(subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function");
  }

  subClass.prototype = Object.create(superClass && superClass.prototype, {
    constructor: {
      value: subClass,
      writable: true,
      configurable: true
    }
  });
  if (superClass) _setPrototypeOf(subClass, superClass);
}

function _getPrototypeOf(o) {
  _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
    return o.__proto__ || Object.getPrototypeOf(o);
  };
  return _getPrototypeOf(o);
}

function _setPrototypeOf(o, p) {
  _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
    o.__proto__ = p;
    return o;
  };

  return _setPrototypeOf(o, p);
}

function _isNativeReflectConstruct() {
  if (typeof Reflect === "undefined" || !Reflect.construct) return false;
  if (Reflect.construct.sham) return false;
  if (typeof Proxy === "function") return true;

  try {
    Date.prototype.toString.call(Reflect.construct(Date, [], function () {}));
    return true;
  } catch (e) {
    return false;
  }
}

function _assertThisInitialized(self) {
  if (self === void 0) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return self;
}

function _possibleConstructorReturn(self, call) {
  if (call && (typeof call === "object" || typeof call === "function")) {
    return call;
  }

  return _assertThisInitialized(self);
}

function _createSuper(Derived) {
  var hasNativeReflectConstruct = _isNativeReflectConstruct();

  return function _createSuperInternal() {
    var Super = _getPrototypeOf(Derived),
        result;

    if (hasNativeReflectConstruct) {
      var NewTarget = _getPrototypeOf(this).constructor;

      result = Reflect.construct(Super, arguments, NewTarget);
    } else {
      result = Super.apply(this, arguments);
    }

    return _possibleConstructorReturn(this, result);
  };
}

function EventDispatcher() {}

Object.assign(EventDispatcher.prototype, {
  /**
  * 添加监听器
  * @param type{string} 监听器类型
  * @param listener{function} 方法
  * @param mutexStatus{boolean} 互斥开关
  */
  addEventListener: function addEventListener(type, listener) {
    var mutexStatus = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
    if (this._listeners === undefined) this._listeners = {};
    this._mutex = this._mutex || {};
    var mutex = this._mutex;
    var listeners = this._listeners;

    if (listeners[type] === undefined) {
      listeners[type] = [];
    }

    if (listeners[type].indexOf(listener) === -1) {
      // 如果启用功能互斥
      if (mutexStatus) {
        mutex[type] = listener;
      }

      listeners[type].push(listener);
    }
  },
  hasEventListener: function hasEventListener(type, listener) {
    if (this._listeners === undefined) return false;
    var listeners = this._listeners;
    return listeners[type] !== undefined && listeners[type].indexOf(listener) !== -1;
  },
  removeEventListener: function removeEventListener(type, listener) {
    if (this._listeners === undefined) return;
    var listeners = this._listeners;
    var listenerArray = listeners[type]; // 移除指定的功能互斥

    if (this._mutex[type] === listener) {
      this._mutex[type] = null;
    }

    if (listenerArray !== undefined) {
      var index = listenerArray.indexOf(listener);

      if (index !== -1) {
        listenerArray.splice(index, 1);
      }
    }
  },

  /**
  * 派发事件
  * @param event{{type: string, message?: *}}
  */
  dispatchEvent: function dispatchEvent(event) {
    var _this = this;

    if (this._listeners === undefined) return;
    var listeners = this._listeners;
    var listenerArray = listeners[event.type];

    if (listenerArray !== undefined) {
      event.target = this; // Make a copy, in case listeners are removed while iterating.

      var array = listenerArray.slice(0);

      if (this._mutex[event.type]) {
        var find = array.find(function (item) {
          return item === _this._mutex[event.type];
        });
        find.call(this, event); // console.log(' 事件互斥已启动')

        return;
      }

      for (var i = 0, l = array.length; i < l; i++) {
        array[i].call(this, event);
      }
    }
  },
  removeAllListener: function removeAllListener() {
    this._mutex = {};

    for (var key in this._listeners) {
      this._listeners[key] = [];
    }
  }
});

// 事件管理类型
var EventConstant = {
  CLICK: 'CLICK',
  //鼠标左键点击事件 
  LEFT_DOWN: 'LEFT_DOWN',
  //鼠标左键按下事件 
  LEFT_UP: 'LEFT_UP',
  //鼠标左键抬起事件 
  MOUSE_MOVE: 'MOUSE_MOVE',
  //鼠标移动事件 
  RIGHT_CLICK: 'RIGHT_CLICK',
  //鼠标右键点击事件 
  LEFT_DOWN_MOUSE_MOVE: 'LEFT_DOWN_MOUSE_MOVE',
  //鼠标左键点击时移动事件 
  RENDER: 'RENDER',
  //渲染事件 
  KEYUP: 'KEYUP',
  //键盘抬起事件 
  KEYDOWN: 'KEYDOWN' //键盘按下事件 

};

var EventManager = /*#__PURE__*/function (_EventDispatcher) {
  _inherits(EventManager, _EventDispatcher);

  var _super = _createSuper(EventManager);

  /**
   * 视图对象
   * @type {Viewer}
   */
  // viewer = null

  /**
   * 事件处理器
   * @type{Cesium.ScreenSpaceEventHandler}
   */
  // handler = null

  /**
   * 按下左键
   * @type {boolean}
   */
  // press = false

  /**
   * 创建事件管理工具
   * @param viewer
   */
  function EventManager(viewer) {
    var _this;

    _classCallCheck(this, EventManager);

    _this = _super.call(this);
    _this.viewer = viewer; // 创建事件管理器

    _this.handler = new Cesium.ScreenSpaceEventHandler(_this.viewer.scene.canvas); // 派发左键单击事件

    _this.handler.setInputAction(function (e) {
      _this.dispatchEvent({
        type: EventConstant.CLICK,
        message: e
      });
    }, Cesium.ScreenSpaceEventType.LEFT_CLICK); // 左键按下事件


    _this.handler.setInputAction(function (e) {
      _this.press = true;

      _this.dispatchEvent({
        type: EventConstant.LEFT_DOWN,
        message: e
      });
    }, Cesium.ScreenSpaceEventType.LEFT_DOWN); // 右键按下事件


    _this.handler.setInputAction(function (e) {
      _this.press = false;

      _this.dispatchEvent({
        type: EventConstant.LEFT_UP,
        message: e
      });
    }, Cesium.ScreenSpaceEventType.LEFT_UP); // 派发右键单击事件


    _this.handler.setInputAction(function (e) {
      _this.dispatchEvent({
        type: EventConstant.RIGHT_CLICK,
        message: e
      });
    }, Cesium.ScreenSpaceEventType.RIGHT_CLICK); // 鼠标移动事件


    _this.handler.setInputAction(function (e) {
      // 左键按下移动事件
      if (_this.press) {
        _this.dispatchEvent({
          type: EventConstant.LEFT_DOWN_MOUSE_MOVE,
          message: e
        });
      }

      _this.dispatchEvent({
        type: EventConstant.MOUSE_MOVE,
        message: e
      });
    }, Cesium.ScreenSpaceEventType.MOUSE_MOVE); // // 派发渲染事件
    // this.viewer.scene.postRender.addEventListener((e, time) => {
    //     TWEEN && TWEEN.update()
    //     this.viewer.stats && this.viewer.stats.update()
    //     this.dispatchEvent({
    //         type: EventConstant.RENDER,
    //         message: {
    //             scene: e,
    //             time: time
    //         }
    //     })
    // })
    // // 键盘抬起事件
    // document.addEventListener(EventConstant.KEYUP, (e) => {
    //     this.dispatchEvent({
    //         type: EventConstant.KEYUP,
    //         message: {
    //             e: e
    //         }
    //     })
    // })
    // // 键盘按下事件
    // document.addEventListener(EventConstant.KEYDOWN, (e) => {
    //     this.dispatchEvent({
    //         type: EventConstant.KEYDOWN,
    //         message: {
    //             e: e
    //         }
    //     })
    // })


    return _this;
  }
  /**
   * 添加相机位置监听方法
   * @param fn{Function} 监听方法
   */


  _createClass(EventManager, [{
    key: "addCameraMoveListener",
    value: function addCameraMoveListener(fn) {
      this.viewer.camera.changed.addEventListener(fn);
    }
    /**
     * 移除相机位置监听
     * @param fn{Function} 监听方法
     */

  }, {
    key: "removeCameraMoveListener",
    value: function removeCameraMoveListener(fn) {
      this.viewer.camera.changed.removeEventListener(fn);
    }
  }]);

  return EventManager;
}(EventDispatcher);

function createTooltip(frameDiv) {
  var tooltip = function tooltip(frameDiv) {
    var div = document.createElement('DIV');
    div.className = "tooltip";
    this._div = div;
    this.message = '';
    frameDiv.appendChild(div);
  };

  tooltip.prototype.setVisible = function (visible) {
    if (visible) {
      this._div.style.right = '10px';
    } else {
      this._div.style.right = '-300px';
    }
  };

  tooltip.prototype.showAt = function (message, top) {
    //top:200px => string
    if (top) {
      this._div.style.top = top;
    }

    if (message) {
      this.setVisible(true);
      this._div.innerHTML = message;
    }
  };

  return new tooltip(frameDiv);
}

var ResourceCN = {
  showRenderLoopErrors: '渲染时发生错误，已停止渲染。',
  AttributeError: '该组件props没有这个属性：',
  NoPickPositionSupported: "不支持深度纹理,无法绘制多边形，地形操作功能无法使用！",
  NoTerrain: "请在地形里使用地形组件！",
  initViewerWarn: '请先初始化viewer!',
  MoveMouseHeightBox: '点击鼠标左键结束矩形绘制，移动鼠标绘制box高度',
  RightClickEndDrawing: '右键单击结束绘制',
  LeftClickBottomBox: '点击鼠标左键，开始绘制矩形作为box底面',
  ClickModelAddBox: '点击模型，添加裁剪盒子',
  SkyLineWarn: "获取天际线体前，请先绘制天际线！",
  SkyLineBody: '天际线体',
  ShadowqueryWarn: "此操作需要先开启阴影！",
  VeiwshedBody: '可视体',
  VeiwshedBodyHidden: '不可视体',
  EchartsErr: "二维显示需要echarts支持，未找到相关依赖！",
  BaseMapImg: '底图',
  tip1: '<p>点击左键确定操作区域中间点</p><p>右键单击结束绘制</p>'
};

// 组件内部的语言资源：主要包括提示信息
var currentLanguage, Resource;
var cookieLanguage = getLang().toLowerCase();

function getLang() {
  //浏览器语言  IE用browserLanguage，非IE使用language进行判断
  var lang = (navigator.language || navigator.browserLanguage).toLowerCase();
  window.lang = lang; //判断portal设置语言 通过cookie获取
  //   const cookies = document.cookie.split(';');
  //   if (cookies.length > 0) {
  //     cookies.forEach(function (cookie) {
  //       const arr = cookie.split('=');
  //       if (arr[0].toLowerCase().trim() === 'language') {
  //         lang = arr[1];
  //         return;
  //       }
  //     });
  //   }

  return lang;
}

if (cookieLanguage !== undefined) {
  currentLanguage = cookieLanguage;
} else {
  currentLanguage = (navigator.language || navigator.browserLanguage).toLowerCase(); // 获取当前浏览器的语言
}

if (currentLanguage.startsWith('zh')) {
  Resource = ResourceCN;
} else if (currentLanguage.startsWith('ja')) {
  Resource = ResourceCN;
} else {
  Resource = ResourceCN;
}

var resource = Resource;

//初始化地球 

function initViewer(props, callback) {
  //初始化viewer
  if (window.viewer) {
    // window.viewer.destroy();
    window.viewer = null; // return;
  }

  var viewer;
  var isPCBroswer = window.isPCBroswer = Cesium.FeatureDetection.isPCBroswer();

  if (isPCBroswer) {
    viewer = new Cesium.Viewer("cesiumContainer", {
      selectionIndicator: false,
      timeline: true,
      baseLayerPicker: false,
      //shadows: true,
      infoBox: false,
      // geocoder: true,  //查询
      // skyBox: false, // 关闭天空盒会一同关闭太阳，场景会变暗
      navigation: false // contextOptions: {
      //   requestWebgl2: true
      // }

    }); // 太阳光默认打开
    // viewer.scene.globe.enableLighting = true;
    //隐藏时间线控件

    document.getElementsByClassName("cesium-viewer-timelineContainer")[0].style.visibility = "hidden";
  } else {
    // 手机端
    viewer = new Cesium.Viewer("cesiumContainer", {
      selectionIndicator: false,
      infoBox: false,
      skyBox: false,
      navigation: false,
      contextOptions: {
        requestWebgl2: true
      }
    });
    var scene = viewer.scene;

    if (Cesium.defined(scene.sun)) {
      scene.globe.enableLighting = false;
    }

    if (Cesium.defined(scene.moon)) {
      scene.moon.show = false;
    }

    document.documentElement.style.height = window.innerHeight + "px";
    document.addEventListener("touchmove", function (e) {
      e.preventDefault();
    }, false);
  }

  viewer.scene.debugShowFramesPerSecond = true; //帧率

  viewer.scene.globe.baseColor = Cesium.Color.BLACK; // 没有影像图层时地球的底色
  // viewer.scene.globe.depthTestAgainstTerrain = false; //地形深度

  window.viewer = viewer;
  window.scene = viewer.scene;
  viewer.eventManager = new EventManager(viewer); //添加事件管理派发

  var widget = viewer.cesiumWidget;
  actions.setIsViewer(true); //初始化viewer标志 

  if (viewer.geocoder) {
    // 请开发者自行到supermap online官网（http://www.supermapol.com/）申请key
    viewer.geocoder.viewModel.geoKey = "fvV2osxwuZWlY0wJb8FEb2i5"; // document.querySelector(".cesium-geocoder-input").placeholder =
    //   Resource.searchPlaceHolder;  //语言配置，后面维护
  }

  if (!window.tooltip) {
    window.tooltip = createTooltip(viewer._element);
  }

  function openingAnimation() {
    viewer.camera.flyTo({
      destination: new Cesium.Cartesian3(6788287.844465209, -41980756.10214644, 29619220.04004376),
      duration: 0,
      complete: function complete() {
        viewer.camera.flyTo({
          destination: new Cesium.Cartesian3.fromDegrees(110.60396458865515, 34.54408834959379, 30644793.325518917),
          duration: 5
        });
      }
    });
  } // 添加图层


  try {
    if (props && props.openingAnimation) {
      openingAnimation();
    }

    if (props && props.afterInitviewer) {
      props.afterInitviewer();
    }

    if (props && props.sceneUrl) {
      addScene(props.sceneUrl, {}, props.addLayerCallback);
    }

    if (props && props.s3mScps) {
      addS3mLayers(props.s3mScps, props.addLayerCallback);
    }
  } catch (e) {
    if (widget._showRenderLoopErrors) {
      var title = resource.showRenderLoopErrors;
      widget.showErrorPanel(title, undefined, e);
    }
  }

  onBeforeUnmount(function () {
    viewer.destroy();
    window.viewer = undefined;
    window.scene = undefined;
  });
}

var script = {
  name: "Sm3dViewer",
  props: {
    sceneUrl: {
      //场景接口
      type: String
    },
    s3mScps: {
      //s3m图层接口
      type: Array
    },
    afterInitviewer: {
      //初始化viewer后回调函数
      type: Function
    },
    addLayerCallback: {
      //默认添加图层回调函数
      type: Function
    },
    openingAnimation: {
      //开场动画
      type: Boolean
    }
  },
  setup: function setup(props) {
    onMounted(function () {
      initViewer(props);
    });
  }
};

var _hoisted_1 = {
  id: "cesiumContainer",
  ref: "viewer"
};
function render(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("div", _hoisted_1, [renderSlot(_ctx.$slots, "default")], 512
  /* NEED_PATCH */
  );
}

script.render = render;
script.__file = "src/components/viewer/viewer.vue";

// import initResource from '../../resource/index.js'  //语言文件

script.install = function (app) {
  // initResource(app);
  // initDrag(app);
  app.component(script.name, script);
};

export default script;
